@@ -6,19 +6,18 @@
 !  Largo Pontecorvo 5                                         !
 !  56127 Pisa                                                 !
 !  Italy                                                      !
-!  Version 1.3 - March 2007                                   !
+!  Version 2.1 - June  2009                                   !
 !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 !
 !
 module fi_int
 interface
-SUBROUTINE fi(A, doshift, method, eps, maxit, x0, G, drift, err)
+SUBROUTINE fi(A, ds, method, eps, maxit, x0, G, drift, err)
 integer,parameter::dp=kind(0.d0)
   REAL(dp), DIMENSION(:,:,:):: a
   REAL(dp), DIMENSION(:,:) :: g, x0
   REAL(dp) :: eps,err,drift
-  integer :: method, maxit
-  logical :: doshift
+  integer :: method, maxit, ds
 end SUBROUTINE fi
 end interface
 
