@@ -6,7 +6,7 @@
 !  Largo Pontecorvo 5                                         !
 !  56127 Pisa                                                 !
 !  Italy                                                      !
-!  Version 1.3 - March 2007                                   !
+!  Version 2.1 - June  2009                                   !
 !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 !
 !
@@ -22,13 +22,6 @@ integer,parameter::dp=kind(0.d0)
 end SUBROUTINE is
 end interface
 
-interface
-function drft_mg1(a)
-integer,parameter::dp=kind(0.d0)
-  real(dp),dimension(:,:,:)::a
-  real(dp)::drft_mg1
-end function drft_mg1
 
-end interface
 end module is_int
 
