@@ -6,7 +6,7 @@
 !  Largo Pontecorvo 5                                         !
 !  56127 Pisa                                                 !
 !  Italy                                                      !
-!  Version 1.3 - March 2007                                   !
+!  Version 2.1 - June  2009                                   !
 !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 !
 !
@@ -15,7 +15,6 @@ subroutine qbdpi(Am1, A0, A1, Bm1, B0, B1, R, maxnc, epspi, pi0,pi,pinc)
   use smc_tools
   USE f95_lapack
   use smc_int, only:gth
-  use ponte_f_f, only: debug,verb,wout
   implicit none
   
   integer :: maxnc,pinc
@@ -37,7 +36,11 @@ subroutine qbdpi(Am1, A0, A1, Bm1, B0, B1, R, maxnc, epspi, pi0,pi,pinc)
    if(allocated(y))deallocate(y)
    if(allocated(v))deallocate(v)
    allocate(aux(m,m),aux1(n,n),aux2(m+n,m+n),x(m),y(n),v(m+n),stat=info)
-   if(info/=0) return
+   if (info/=0) then
+        if(debug) write(*,*) "qbdpi: info=",info
+        info=1000
+        return
+   endif
    aux1=-r
    do i=1,n
       aux1(i,i)=aux1(i,i)+1.d0
@@ -48,8 +51,8 @@ subroutine qbdpi(Am1, A0, A1, Bm1, B0, B1, R, maxnc, epspi, pi0,pi,pinc)
    if(.not. present(B1)) then
       aux=B0+matmul(R,Bm1)
       call gth(aux,x)
-!write(*,*)"alfa=",(1.d0/dot_product(x,y))
-!write(*,*)"x=",x
+!if(debug) write(*,*)"alfa=",(1.d0/dot_product(x,y))
+!if(debug) write(*,*)"x=",x
       x=x*(1.d0/dot_product(x,y))
       pi0=x
       sumpi=sum(x)
@@ -106,8 +109,8 @@ subroutine qbdpi(Am1, A0, A1, Bm1, B0, B1, R, maxnc, epspi, pi0,pi,pinc)
 !! verificare alfa  
       alpha=sum(v(1:m))+dot_product(v(m+1:m+n),y)
       alpha=1.d0/alpha
-!write(*,*)"alfa=",alpha
-!write(*,*)v
+!if(debug) write(*,*)"alfa=",alpha
+!if(debug) write(*,*)v
       v=v*alpha
       pi0=v(1:m)
       sumpi=sum(pi0)
@@ -163,6 +166,12 @@ subroutine qbdpi(Am1, A0, A1, Bm1, B0, B1, R, maxnc, epspi, pi0,pi,pinc)
       
    end if
    pinc=count
+   if(allocated(aux))deallocate(aux)
+   if(allocated(aux1))deallocate(aux1)
+   if(allocated(aux2))deallocate(aux2)
+   if(allocated(x))deallocate(x)
+   if(allocated(y))deallocate(y)
+   if(allocated(v))deallocate(v)
  end subroutine qbdpi
 
 
@@ -176,7 +185,6 @@ subroutine qbdpi(Am1, A0, A1, Bm1, B0, B1, R, maxnc, epspi, pi0,pi,pinc)
    use smc_tools
    USE f95_lapack
    use smc_int, only:gth
-   use ponte_f_f, only: debug,verb,wout
    implicit none
    
    integer :: maxnc, pinc
@@ -204,14 +212,20 @@ subroutine qbdpi(Am1, A0, A1, Bm1, B0, B1, R, maxnc, epspi, pi0,pi,pinc)
    if(allocated(SumA))deallocate(SumA)
    if(allocated(SumB))deallocate(SumB)
    allocate(Bstar(m,n,nbb),Astar(n,n,nba),Astari(n,n),B0star(m,n),SumA(n,n),SumB(m,n),stat=info)
-    if(info/=0) return
-
-    if(allocated(y))deallocate(y)
+   if (info/=0) then
+        if(debug) write(*,*) "mg1pi: info=",info
+        info=1000
+        return
+   endif
+   if(allocated(y))deallocate(y)
    if(allocated(x))deallocate(x)
    if(allocated(ipiv))deallocate(ipiv)
-
    allocate(y(n),ipiv(n),x(m),stat=info)
-   if(info/=0) return
+   if (info/=0) then
+        if(debug) write(*,*) "mg1pi: info=",info
+        info=1000
+        return
+   endif
    
 10 FORMAT("*")
 
@@ -233,11 +247,11 @@ if(debug) write(*,*) "mg1_pi: dim A =",n,"dim B =",m," blocks A =",nba,"blocks B
    end do
    call la_getrf(Astari,ipiv)
    call la_getri(Astari,ipiv,info)
-   if(info/=0)then
-      write(wout,*)"Error in la_getri called by mg1_pi: info=",info
-      call print_it
-      return
-   end if
+  if (info/=0) then
+        if(debug) write(*,*) "mg1_pi:la_gestri info=",info
+        info=2000
+        return
+  endif
 
    ! compute B_0^*
    if(.not. present(Bm1)) then
@@ -257,11 +271,11 @@ if(debug) write(*,*) "mg1_pi: dim A =",n,"dim B =",m," blocks A =",nba,"blocks B
    end do
    call la_getrf(SumA,ipiv)
    call la_getri(SumA,ipiv,info)
-   if(info/=0)then
-       write(wout,*)"Error in la_getri called by mg1_pi: info=",info
-      call print_it
-       return
-   end if
+   if (info/=0) then
+        if(debug) write(*,*) "mg1_pi:la_gestri info=",info
+        info=2000
+        return
+    endif
 
 ! compute the normalization factor and normalize pi0
 ! alpha=1/(1+pi0 sum_{i>=1}B_i^* (I-sum_{i>=0} A_i^*)^{-1} e)
@@ -300,7 +314,7 @@ if(debug) write(*,*) "mg1_pi: dim A =",n,"dim B =",m," blocks A =",nba,"blocks B
       y=0.d0
       if(count<=nbb) y=matmul(pi0,Bstar(:,:,count))   !matmul(Bstar(:,:,count),pi0)
       do i=max(1,count-nba+2),count-1
-! write(*,*)"count-i+2=",count-i+2, "nba=",nba,"count=",count,"i=",i
+! if(debug) write(*,*)"count-i+2=",count-i+2, "nba=",nba,"count=",count,"i=",i
 !         y=y+matmul(Astar(:,:,count-i+2),pi(:,i))
          y=y+matmul(Pi(:,i),Astar(:,:,count-i+2))
       end do
@@ -326,7 +340,16 @@ if(debug) write(*,*) "mg1_pi: dim A =",n,"dim B =",m," blocks A =",nba,"blocks B
              end if
 
    pinc=count
-if(debug) write(*,*) "mg1_pi: exiting with pinc=",pinc
+   if(allocated(Bstar))deallocate(Bstar)
+   if(allocated(Astar))deallocate(Astar)
+   if(allocated(Astari))deallocate(Astari)
+   if(allocated(B0star))deallocate(B0star)
+   if(allocated(SumA))deallocate(SumA)
+   if(allocated(SumB))deallocate(SumB)
+   if(allocated(y))deallocate(y)
+   if(allocated(x))deallocate(x)
+   if(allocated(ipiv))deallocate(ipiv)
+if(debug)  write(*,*) "mg1_pi: exiting with pinc=",pinc
 end subroutine mg1pi
 
 
@@ -334,7 +357,6 @@ subroutine gm1pi(A, B, B0, Bm1, R, maxnc, epspi, pi0, pi, pinc)
    use smc_tools
    USE f95_lapack
    use smc_int, only:gth
-   use ponte_f_f, only: debug,verb,wout
    implicit none
    
    integer :: maxnc, pinc
@@ -362,7 +384,11 @@ subroutine gm1pi(A, B, B0, Bm1, R, maxnc, epspi, pi0, pi, pinc)
    if(allocated(auxn))deallocate(auxn)
    if(allocated(auxm))deallocate(auxm)
    allocate(B0star(m,n),auxn(n,n),auxm(m,m),x(n),y(n),ipiv(n),stat=info)
-   if(info/=0) return
+   if (info/=0) then
+        if(debug) write(*,*) "gm1pi: info=",info
+        info=1000
+        return
+   endif
    b0star=b(:,:,nbb)
    do i=nbb-1,1,-1
       b0star=matmul(r,b0star)+b(:,:,i)
@@ -483,5 +509,11 @@ subroutine gm1pi(A, B, B0, Bm1, R, maxnc, epspi, pi0, pi, pinc)
 
    end if
    pinc=count
+   if(allocated(B0star))deallocate(B0star)
+   if(allocated(x))deallocate(x)
+   if(allocated(y))deallocate(y)
+   if(allocated(ipiv))deallocate(ipiv)
+   if(allocated(auxn))deallocate(auxn)
+   if(allocated(auxm))deallocate(auxm)
  end subroutine gm1pi
  
