@@ -37,7 +37,7 @@
 !=========================================================================!
 !  Included in                                                            !
 !  Structured Markov Chains Solver      [  SMCSolver  ]                   !
-!  Version 1.3 - March 2007                                               !
+!  Version 2.1 - June  2009                                               !
 !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 
 subroutine fillroots(n)
@@ -50,17 +50,33 @@ subroutine fillroots(n)
   if(allocated(wr)) k=size(wr,1)
   if(.not.allocated(wwr))then
      allocate(wwr(n),stat=info)
-     if(info/=0)return
+     if (info/=0) then
+        if(debug) write(*,*) "fillroots: info=",info
+        info=1000
+        return
+     endif
      allocate(wwi(n),stat=info)
-     if(info/=0)return
+     if (info/=0) then
+        if(debug) write(*,*) "fillroots: info=",info
+        info=1000
+        return
+     endif
      allocate(wr(n),stat=info)
-     if(info/=0)return
+     if (info/=0) then
+        if(debug) write(*,*) "fillroots: info=",info
+        info=1000
+        return
+     endif
      allocate(wi(n),stat=info)
-     if(info/=0)return
+     if (info/=0) then
+        if(debug) write(*,*) "fillroots: info=",info
+        info=1000
+        return
+     endif
      loop1 : do i=1,n
-	pi2=(i-1)*pi
-	wwr(i)=cos(pi2)
-	wwi(i)=sin(pi2)
+     pi2=(i-1)*pi
+     wwr(i)=cos(pi2)
+     wwi(i)=sin(pi2)
      end do loop1
      wr=wwr
      wi=wwi
@@ -73,25 +89,41 @@ subroutine fillroots(n)
   if (allocated(wr)) deallocate(wr)
   if (allocated(wi)) deallocate(wi)
   allocate(wr(n),stat=info)
-  if(info/=0)return
+     if (info/=0) then
+        if(debug) write(*,*) "fillroots: info=",info
+        info=1000
+        return
+     endif
   allocate(wi(n),stat=info)
-  if(info/=0)return
+     if (info/=0) then
+        if(debug) write(*,*) "fillroots: info=",info
+        info=1000
+        return
+     endif
   m=n/k
   loop2 : do i=1,k
      mi1=m*(i-1)
      wr(mi1+1)=wwr(i)
      wi(mi1+1)=wwi(i)
      loop3 : do j=2,m
-	wr(mi1+j)=cos(pi*(mi1+j-1))
-	wi(mi1+j)=sin(pi*(mi1+j-1))
+     wr(mi1+j)=cos(pi*(mi1+j-1))
+     wi(mi1+j)=sin(pi*(mi1+j-1))
      end do loop3
   end do loop2
   if (allocated(wwr)) deallocate(wwr)
   if (allocated(wwi)) deallocate(wwi)
   allocate(wwr(n),stat=info)
-  if(info/=0)return
+     if (info/=0) then
+        if(debug) write(*,*) "fillroots: info=",info
+        info=1000
+        return
+     endif
   allocate(wwi(n),stat=info)
-  if(info/=0)return
+     if (info/=0) then
+        if(debug) write(*,*) "fillroots: info=",info
+        info=1000
+        return
+     endif
   wwr=wr
   wwi=wi
 end subroutine fillroots
@@ -133,38 +165,38 @@ subroutine  ifft1(x,y)
      ne=nmax/n2  +1
      na=1
      loop2 : do j=1,n4
-	na3=3*(na-1)+1
-	cc1=wr(na)
-	ss1=wi(na)
-	cc3=wr(na3)
-	ss3=wi(na3)
-	na=j*(ne-1)+1
-	is=j
-	id=2*n2
-40	loop3 : do i0=is,n-1,id
-	   i1=i0+n4
-	   i2=i1+n4
-	   i3=i2+n4
-	   r1=x(i0)-x(i2)
-	   x(i0)=x(i0)+x(i2)
-	   r2=x(i1)-x(i3)
-	   x(i1)=x(i1)+x(i3)
-	   s1=y(i0)-y(i2)
-	   y(i0)=y(i0)+y(i2)
-	   s2=y(i1)-y(i3)
-	   y(i1)=y(i1)+y(i3)
-	   s3=r1-s2
-	   r1=r1+s2
-	   s2=r2-s1
-	   r2=r2+s1
-	   x(i2)=r1*cc1-s2*ss1
-	   y(i2)=-s2*cc1-r1*ss1
-	   x(i3)=s3*cc3+r2*ss3
-	   y(i3)=r2*cc3-s3*ss3
-	end do loop3
-	is=2*id-n2+j
-	id=4*id
-	if (is<n) goto 40
+     na3=3*(na-1)+1
+     cc1=wr(na)
+     ss1=wi(na)
+     cc3=wr(na3)
+     ss3=wi(na3)
+     na=j*(ne-1)+1
+     is=j
+     id=2*n2
+40   loop3 : do i0=is,n-1,id
+     i1=i0+n4
+     i2=i1+n4
+     i3=i2+n4
+     r1=x(i0)-x(i2)
+     x(i0)=x(i0)+x(i2)
+     r2=x(i1)-x(i3)
+     x(i1)=x(i1)+x(i3)
+     s1=y(i0)-y(i2)
+     y(i0)=y(i0)+y(i2)
+     s2=y(i1)-y(i3)
+     y(i1)=y(i1)+y(i3)
+     s3=r1-s2
+     r1=r1+s2
+     s2=r2-s1
+     r2=r2+s1
+     x(i2)=r1*cc1-s2*ss1
+     y(i2)=-s2*cc1-r1*ss1
+     x(i3)=s3*cc3+r2*ss3
+     y(i3)=r2*cc3-s3*ss3
+end do loop3
+     is=2*id-n2+j
+     id=4*id
+     if (is<n) goto 40
      end do loop2
   end do loop1
   is=1
@@ -275,38 +307,38 @@ subroutine  fft1(x,y)
      ne=nmax/n2
      na=1
      loop20 : do  j=1,n4
-	na3=3*(na-1)+1
-	cc1=wr(na)
-	ss1=wi(na)
-	cc3=wr(na3)
-	ss3=wi(na3)
-	na=j*ne+1
-	is=j
-	id=2*n2
-40	loop30 : do  i0=is,n-1,id
-	   i1=i0+n4
-	   i2=i1+n4
-	   i3=i2+n4
-	   r1=x(i2)*cc1-y(i2)*ss1
-	   s1=-y(i2)*cc1-x(i2)*ss1
-	   r2=x(i3)*cc3-y(i3)*ss3
-	   s2=-y(i3)*cc3-x(i3)*ss3
-	   r3=r1+r2
-	   r2=r1-r2
-	   r1=s1+s2
-	   s2=s1-s2
-	   x(i2)=x(i0)-r3
-	   x(i0)=x(i0)+r3
-	   x(i3)=x(i1)-s2
-	   x(i1)=x(i1)+s2
-	   y(i2)=y(i0)+r1
-	   y(i0)=y(i0)-r1
-	   y(i3)=y(i1)-r2
-	   y(i1)=y(i1)+r2
-	end do loop30
-        is=2*id-n2+j
-        id=4*id
-        if(is<n)goto 40
+     na3=3*(na-1)+1
+     cc1=wr(na)
+     ss1=wi(na)
+     cc3=wr(na3)
+     ss3=wi(na3)
+     na=j*ne+1
+     is=j
+     id=2*n2
+40   loop30 : do  i0=is,n-1,id
+     i1=i0+n4
+     i2=i1+n4
+     i3=i2+n4
+     r1=x(i2)*cc1-y(i2)*ss1
+     s1=-y(i2)*cc1-x(i2)*ss1
+     r2=x(i3)*cc3-y(i3)*ss3
+     s2=-y(i3)*cc3-x(i3)*ss3
+     r3=r1+r2
+     r2=r1-r2
+     r1=s1+s2
+     s2=s1-s2
+     x(i2)=x(i0)-r3
+     x(i0)=x(i0)+r3
+     x(i3)=x(i1)-s2
+     x(i1)=x(i1)+s2
+     y(i2)=y(i0)+r1
+     y(i0)=y(i0)-r1
+     y(i3)=y(i1)-r2
+     y(i1)=y(i1)+r2
+end do loop30
+     is=2*id-n2+j
+     id=4*id
+     if(is<n)goto 40
      end do loop20
   end do loop10
 end subroutine fft1
@@ -342,10 +374,18 @@ subroutine ffts1(u,v)
   if(2**km<nmax)km=km+1
   if(allocated(zr)) deallocate(zr)
   allocate(zr(n/2),stat=info)
-  if(info/=0)return
+     if (info/=0) then
+        if(debug) write(*,*) "ffts1: info=",info
+        info=1000
+        return
+     endif
   if(allocated(zi)) deallocate(zi)
   allocate(zi(n/2),stat=info)
-  if(info/=0)return
+     if (info/=0) then
+        if(debug) write(*,*) "ffts1: info=",info
+        info=1000
+        return
+     endif
   loop20 : do l=0,n/2-1
      zr(l+1)=u(2*l+1)
      zi(l+1)=u(2*l+2)
@@ -396,10 +436,18 @@ subroutine ffts2(u,v)
   if(2**km<nmax)km=km+1
   if(allocated(zr))deallocate(zr)
   allocate(zr(n/2),stat=info)
-  if(info/=0)return
+     if (info/=0) then
+        if(debug) write(*,*) "ffts2: info=",info
+        info=1000
+        return
+     endif
   if(allocated(zi))deallocate(zi)
   allocate(zi(n/2),stat=info)
-  if(info/=0)return
+    if (info/=0) then
+        if(debug) write(*,*) "ffts2: info=",info
+        info=1000
+        return
+     endif
   uq=1.d0/2.d0      
   loop20 : do l=0,n/2-1
      zr(l+1)=u(2*l+1)
@@ -481,7 +529,7 @@ subroutine iffts1(u,v)
   real(dp), dimension(:), allocatable  :: zr, zi
   real(dp)                         :: dr
   integer                          :: l, km, n, ln, nmax, nm, &
-       k1, k2, mm, ml
+       k1,  mm, ml
   n=size(u,1)
   ln=log(n*1.d0)/log(2.d0)
   if(2**ln<n)ln=ln+1
@@ -491,10 +539,18 @@ subroutine iffts1(u,v)
   if(2**km<nmax)km=km+1
   if(allocated(zr))deallocate(zr)
   allocate(zr(n/2),stat=info)
-  if(info/=0)return
+  if (info/=0) then
+        if(debug) write(*,*) "iffts1: info=",info
+        info=1000
+        return
+  endif
   if(allocated(zi))deallocate(zi)
   allocate(zi(n/2),stat=info)
-  if(info/=0)return
+  if (info/=0) then
+        if(debug) write(*,*) "iffts1: info=",info
+        info=1000
+        return
+  endif
   mm=2**(km-ln)
   nm=n/2
   dr=1.0d0/2.0d0
@@ -541,7 +597,7 @@ subroutine iffts2(u,v,t)
   real(dp), dimension(:), allocatable  :: zr, zi
   real(dp)                     :: dr
   integer                      :: l, km, n, ln, nmax, &
-       n2, mm, nm, k1, k2, ml
+       mm, nm,  ml
   n=size(u,1)
   ln=log(n*1.d0)/log(2.d0)
   if(2**ln<n)ln=ln+1
@@ -551,17 +607,25 @@ subroutine iffts2(u,v,t)
   if(2**km<nmax)km=km+1
   if(allocated(zr))deallocate(zr)
   allocate(zr(n/2),stat=info)
-  if(info/=0)return
+  if (info/=0) then
+        if(debug) write(*,*) "iffts2: info=",info
+        info=1000
+        return
+  endif
   if(allocated(zi))deallocate(zi)
   allocate(zi(n/2),stat=info)
-  if(info/=0)return
+  if (info/=0) then
+        if(debug) write(*,*) "iffts2: info=",info
+        info=1000
+        return
+  endif
   mm=2**(km-ln-1)
   nm=n/2
   !n2=2*n
   dr=1.0d0/2.0d0
   loop20 : do  l=1,nm
      ml=(2*l-1)*mm+1
-     k1=2*l
+!     k1=2*l
 !     k2=k1+nm
      zr(l)=u(l)+u(nm-l+1)+wr(ml)*(-u(nm+l)-u(n-l+1))
      zr(l)=(zr(l)+wi(ml)*(-u(nm-l+1)+u(l)))*dr
@@ -642,15 +706,23 @@ subroutine ftb1(a,ta)
   endif
   if(allocated(sa))deallocate(sa)
   allocate(sa(n),stat=info)
-  if(info/=0)return
+  if (info/=0) then
+        if(debug) write(*,*) "ftb1: info=",info
+        info=1000
+        return
+  endif
   if(allocated(st))deallocate(st)
   allocate(st(n),stat=info)
-  if(info/=0)return
+  if (info/=0) then
+        if(debug) write(*,*) "ftb1: info=",info
+        info=1000
+        return
+  endif
   loopi : do i=1,nb
      loopj : do j=1,nb
-	sa(:)=a(i,j,:)
-	call ffts1(sa,st)
-	ta(i,j,:)=st(:)
+     sa(:)=a(i,j,:)
+     call ffts1(sa,st)
+     ta(i,j,:)=st(:)
      end do loopj
   end do loopi
   if (allocated(sa)) deallocate(sa)
@@ -687,10 +759,18 @@ subroutine ftb2(a,ta)
   endif
   if(allocated(sa))deallocate(sa)
   allocate(sa(n),stat=info)
-  if(info/=0)return
+  if (info/=0) then
+        if(debug) write(*,*) "ftb2: info=",info
+        info=1000
+        return
+  endif
   if(allocated(st))deallocate(st)
   allocate(st(n),stat=info)
-  if(info/=0)return
+  if (info/=0) then
+        if(debug) write(*,*) "ftb2: info=",info
+        info=1000
+        return
+  endif
   loopi : do i=1,nb
      loopj : do j=1,nb
         sa(:)=a(i,j,:)
@@ -733,15 +813,23 @@ subroutine iftb1(ta,a)
   endif
   if(allocated(st))deallocate(st)
   allocate(st(n),stat=info)
-  if(info/=0)return
+  if (info/=0) then
+        if(debug) write(*,*) "iftb1: info=",info
+        info=1000
+        return
+  endif
   if(allocated(sa))deallocate(sa)
   allocate(sa(n),stat=info)
-  if(info/=0)return
+  if (info/=0) then
+        if(debug) write(*,*) "iftb1: info=",info
+        info=1000
+        return
+  endif
   loopi : do i=1,nb
      loopj : do j=1,nb
-	st(:)=ta(i,j,:) 
-	call iffts1(st,sa)
-	a(i,j,:)=sa(:)
+     st(:)=ta(i,j,:) 
+     call iffts1(st,sa)
+     a(i,j,:)=sa(:)
      end do loopj
   end do loopi
   if (allocated(sa)) deallocate(sa)
@@ -778,7 +866,11 @@ subroutine iftb2(ta,a)
   nb=size(ta,1)
 if(allocated(aux))deallocate(aux)
   allocate(aux(nb,nb,2*n),stat=info)
-if(info/=0)return
+  if (info/=0) then
+        if(debug) write(*,*) "iftb2: info=",info
+        info=1000
+        return
+  endif
   if(n==2)then
      oneh=1.0d0/2.0d0
      aux(:,:,1)=(a(:,:,1)+ta(:,:,1))*oneh
@@ -787,30 +879,50 @@ if(info/=0)return
      aux(:,:,4)=(a(:,:,2)-ta(:,:,2))*oneh
      deallocate(a)
      allocate(a(nb,nb,2*n),stat=info)
-     if(info/=0)return
+     if (info/=0) then
+        if(debug) write(*,*) "iftb2: info=",info
+        info=1000
+        return
+     endif
      a=aux
      return
   endif
   if(allocated(st))deallocate(st)
   allocate(st(n),stat=info)
-     if(info/=0)return
+  if (info/=0) then
+        if(debug) write(*,*) "iftb2: info=",info
+        info=1000
+        return
+  endif
   if(allocated(sa))deallocate(sa)
   allocate(sa(n),stat=info)
-     if(info/=0)return
+  if (info/=0) then
+        if(debug) write(*,*) "iftb2: info=",info
+        info=1000
+        return
+  endif
   if(allocated(t))deallocate(t)
   allocate(t(2*n),stat=info)
-     if(info/=0)return
+  if (info/=0) then
+        if(debug) write(*,*) "iftb2: info=",info
+        info=1000
+        return
+  endif
   loopi : do i=1,nb
      loopj : do j=1,nb
-	st(:)=ta(i,j,:)
-	sa(:)=a(i,j,:)
-	call iffts2(st,sa,t)
-	aux(i,j,:)=t(:)
+     st(:)=ta(i,j,:)
+     sa(:)=a(i,j,:)
+     call iffts2(st,sa,t)
+     aux(i,j,:)=t(:)
      end do loopj
   end do loopi
   if (allocated(a)) deallocate(a)
   allocate(a(nb,nb,2*n),stat=info)
-  if(info/=0)return
+  if (info/=0) then
+        if(debug) write(*,*) "iftb2: info=",info
+        info=1000
+        return
+  endif
   a=aux
   deallocate(st,sa,t,aux)
 end subroutine iftb2
