@@ -6,7 +6,7 @@
  * Largo Pontecorvo 5                                         *
  * 56127 Pisa                                                 *
  * Italy                                                      *
- * Version 1.3 - March 2007                                   *
+ * Version 2.1 - June  2009                                   *
  **************************************************************
  *
  *  edit-a.c - view and edit A  - both callbacks and interfaces
@@ -41,9 +41,10 @@ create_edit_a_window()
 /* GtkWidget *window_edit_a; global */
 GtkWidget *vboxm_edita;
 GtkWidget *hbox1,*hbox2;
-GtkWidget *vbox1,*vbox2;
+GtkWidget *vbox1,*vbox2,*vbox3;
 GtkWidget *vbox11,*vbox14;
 /* GtkWidget *edit_vbox12,*edit_vbox13; globale */
+GtkWidget *hbox31,*hbox32;
 GtkWidget *hsep11,*hsep12,*hsep13; /* separators */
 GtkWidget *label_v11,*label_v12,*label_v13; /* titles for button groups */
 GtkWidget *button_pos_neg;
@@ -56,7 +57,7 @@ GtkWidget *button_range_normal;
 GtkWidget *button_range_adaptive;
 GtkWidget *button_range_block;  
 GSList *range_list = NULL;
-GtkWidget *hsep1,*hsep2,*vsep0,*vsep1,*vsep2; /* separators */
+GtkWidget *hsep1,*hsep2,*hsep3,*hsep4,*vsep0,*vsep1,*vsep2; /* separators */
 GtkWidget *vbox21,*vbox22, *vbox23;
 GtkWidget *label_211,*label_212; /* labels with matrix results */
 GtkWidget *label_221; /* labels with matrix results */
@@ -90,7 +91,9 @@ char buf[256];
 /* window_edit_a */
 window_edit_a=gtk_window_new (GTK_WINDOW_TOPLEVEL);
 gtk_window_set_title (GTK_WINDOW (window_edit_a), "View and Edit  Matrix A");
-gtk_window_set_default_size (GTK_WINDOW (window_edit_a), 720, 700);
+if(is_smallscr==0) gtk_window_set_default_size (GTK_WINDOW (window_edit_a), 720, 700);
+	else  gtk_window_set_default_size (GTK_WINDOW (window_edit_a), 510, 700);
+gtk_window_set_resizable (GTK_WINDOW (window_edit_a),FALSE);
 a_selected_block = pea.block; /* we need this value here */
 gdk_rgb_init();
 
@@ -98,7 +101,7 @@ gdk_rgb_init();
 vboxm_edita = gtk_vbox_new (FALSE, 5);
 gtk_widget_show (vboxm_edita);
 gtk_container_add (GTK_CONTAINER (window_edit_a), vboxm_edita);
-/* divided in four hbox */
+/* divided in four hbox  or 2 if small screen */
 hbox1=gtk_hbox_new(FALSE,5);
 gtk_widget_show(hbox1);
 gtk_box_pack_start (GTK_BOX (vboxm_edita), hbox1, FALSE, FALSE, 5);
@@ -231,8 +234,8 @@ gtk_box_pack_start (GTK_BOX (hbox1), vsep0, FALSE, FALSE, 0);
 /* second vbox in first hbox for matrix display */
 vbox2=gtk_vbox_new(FALSE,5);
 gtk_widget_show(vbox2);
-gtk_box_pack_end (GTK_BOX (hbox1), vbox2, FALSE, FALSE, 0);
-gtk_container_set_border_width (GTK_CONTAINER (vbox2), 10);
+gtk_box_pack_start (GTK_BOX (hbox1), vbox2, FALSE, FALSE, 0);
+gtk_container_set_border_width (GTK_CONTAINER (vbox2), 5);
 /* matrix drawable area */
 gtk_widget_push_visual(gdk_rgb_get_visual());
 gtk_widget_push_colormap(gdk_rgb_get_cmap());
@@ -265,13 +268,23 @@ hsep1 = gtk_hseparator_new();
 gtk_widget_show(hsep1);
 gtk_box_pack_start (GTK_BOX (vboxm_edita), hsep1, FALSE, FALSE, 0);
 
+/* is small screen we use a third vbox on the right */
+if (is_smallscr==1) {
+vbox3=gtk_vbox_new(FALSE,5);
+gtk_box_pack_start (GTK_BOX (hbox1), vbox3, TRUE, TRUE, 0);
+gtk_widget_show(vbox3);
+}
+
 /* second hbox contains various data show boxes */
+/* in small screen they in the vbox3 */
 hbox2=gtk_hbox_new(FALSE,5);
 gtk_widget_show(hbox2);
-gtk_box_pack_start (GTK_BOX (vboxm_edita), hbox2, FALSE, FALSE, 0);
+if (is_smallscr==0) gtk_box_pack_start (GTK_BOX (vboxm_edita), hbox2, FALSE, FALSE, 0);
+/*	else gtk_box_pack_start (GTK_BOX (vbox3), hbox2, FALSE, FALSE, 0);*/
 /* matrix #blocks and dimensions */
 vbox21 = gtk_vbox_new(TRUE,5);
-gtk_box_pack_start (GTK_BOX (hbox2), vbox21, TRUE, TRUE, 0);
+if (is_smallscr==0) gtk_box_pack_start (GTK_BOX (hbox2), vbox21, TRUE, TRUE, 0);
+	else gtk_box_pack_start (GTK_BOX (vbox3), vbox21, TRUE, TRUE, 0);
 gtk_widget_show(vbox21);
 label_211 = gtk_label_new("   Matrix A   ");
 gtk_widget_show(label_211);
@@ -281,12 +294,20 @@ sprintf(buf,"   %d Blocks   dim  %d x %d  ",committed.matrix_a_num,committed.dim
 label_212 = gtk_label_new(buf);
 gtk_widget_show(label_212);
 gtk_box_pack_start (GTK_BOX (vbox21), label_212, FALSE, FALSE, 0);
+if (is_smallscr==0) {
 /* vertical separator */
-vsep1 = gtk_vseparator_new();
-gtk_widget_show(vsep1);
-gtk_box_pack_start (GTK_BOX (hbox2), vsep1, FALSE, FALSE, 0);
+ vsep1 = gtk_vseparator_new();
+ gtk_widget_show(vsep1);
+ gtk_box_pack_start (GTK_BOX (hbox2), vsep1, FALSE, FALSE, 0);
+ } else {
+/* horizontal separator */
+ hsep3 =gtk_hseparator_new();
+ gtk_widget_show(hsep3);
+ gtk_box_pack_start (GTK_BOX (vbox3), hsep3, FALSE, FALSE, 0);
+ }
 vbox22 = gtk_vbox_new(TRUE,0);
-gtk_box_pack_start (GTK_BOX (hbox2), vbox22, TRUE, TRUE, 0);
+if(is_smallscr==0) gtk_box_pack_start (GTK_BOX (hbox2), vbox22, TRUE, TRUE, 0);
+	else gtk_box_pack_start (GTK_BOX (vbox3), vbox22, TRUE, TRUE, 0);
 gtk_widget_show(vbox22);
 sprintf(buf,"Stochasticity Defect");
 label_221 = gtk_label_new(buf);
@@ -296,49 +317,88 @@ sprintf(buf,"  %lg  ",st_def());
 label_222 = gtk_label_new(buf);
 gtk_widget_show(label_222);
 gtk_box_pack_start (GTK_BOX (vbox22), label_222, TRUE, TRUE, 0);
+if (is_smallscr==0) {
 /* vertical separator */
-vsep2 = gtk_vseparator_new();
-gtk_widget_show(vsep2);
-gtk_box_pack_start (GTK_BOX (hbox2), vsep2, FALSE, FALSE, 0);
+ vsep2 = gtk_vseparator_new();
+ gtk_widget_show(vsep2);
+ gtk_box_pack_start (GTK_BOX (hbox2), vsep2, FALSE, FALSE, 0);
+ } else {
+/* horizontal separator */
+ hsep4 =gtk_hseparator_new();
+ gtk_widget_show(hsep4);
+ gtk_box_pack_start (GTK_BOX (vbox3), hsep4, FALSE, FALSE, 0);
+ }
+
 vbox23 = gtk_vbox_new(TRUE,0);
-gtk_box_pack_start (GTK_BOX (hbox2), vbox23, TRUE, TRUE, 0);
+if (is_smallscr==0)gtk_box_pack_start (GTK_BOX (hbox2), vbox23, TRUE, TRUE, 0);
+	else gtk_box_pack_start (GTK_BOX (vbox3), vbox23, TRUE, TRUE, 0);
 gtk_widget_show(vbox23);
-sprintf(buf,"This Block  max=%g  min=%g ",abmax(a_selected_block),abmin(a_selected_block));
+if (is_smallscr==0) sprintf(buf,"This Block:  max=%g  min=%g ",abmax(a_selected_block),abmin(a_selected_block));
+	else sprintf(buf,"This Block: \n max=%g \n min=%g ",abmax(a_selected_block),abmin(a_selected_block));
 label_231 = gtk_label_new(buf);
 gtk_widget_show(label_231);
 gtk_box_pack_start (GTK_BOX (vbox23), label_231, TRUE, TRUE, 0);
-sprintf(buf,"All Blocks max=%g  min=%g ",aamax(),aamin());
+if (is_smallscr==0) sprintf(buf,"All Blocks: max=%g  min=%g ",aamax(),aamin());
+	else sprintf(buf,"All Blocks: \n max=%g \n min=%g ",aamax(),aamin());
 label_232 = gtk_label_new(buf);
 gtk_widget_show(label_232);
 gtk_box_pack_start (GTK_BOX (vbox23), label_232, TRUE, TRUE, 0);
 
+if(is_smallscr==0){
 /* horizontal separator */
-hsep2 = gtk_hseparator_new();
-gtk_widget_show(hsep2);
-gtk_box_pack_start (GTK_BOX (vboxm_edita), hsep2, FALSE, FALSE, 0);
+ hsep2 = gtk_hseparator_new();
+ gtk_widget_show(hsep2);
+ gtk_box_pack_start (GTK_BOX (vboxm_edita), hsep2, FALSE, FALSE, 0);
+} else {
+/* horizontal separator */
+ hsep2 = gtk_hseparator_new();
+ gtk_widget_show(hsep2);
+ gtk_box_pack_start (GTK_BOX (vbox3), hsep2, FALSE, FALSE, 0);
+}
 
 /* third hbox consists in toolbox  */
 /* toolbar begins */
 toolbar_ed = gtk_toolbar_new ();
+if (is_smallscr==1)
+gtk_toolbar_set_orientation(GTK_TOOLBAR (toolbar_ed),GTK_ORIENTATION_VERTICAL);
 gtk_widget_show (toolbar_ed);
-gtk_box_pack_start (GTK_BOX (vboxm_edita), toolbar_ed, FALSE, FALSE, 0);
-gtk_container_set_border_width (GTK_CONTAINER (toolbar_ed), 10);
+if(is_smallscr==0) gtk_box_pack_start (GTK_BOX (vboxm_edita), toolbar_ed, FALSE, FALSE, 0);
+	else  gtk_box_pack_start (GTK_BOX (vbox3), toolbar_ed, FALSE, FALSE, 0);
+gtk_container_set_border_width (GTK_CONTAINER (toolbar_ed), 5);
 gtk_toolbar_set_style (GTK_TOOLBAR (toolbar_ed), GTK_TOOLBAR_BOTH);
+if(is_smallscr==0){
 /* cancel button  first position */
-tmp_toolbar_icon = gtk_image_new_from_stock ("gtk-quit", gtk_toolbar_get_icon_size (GTK_TOOLBAR (toolbar_ed)));
-button_quit_ed = gtk_toolbar_append_element (GTK_TOOLBAR (toolbar_ed),
+ tmp_toolbar_icon = gtk_image_new_from_stock ("gtk-quit", gtk_toolbar_get_icon_size (GTK_TOOLBAR (toolbar_ed)));
+ button_quit_ed = gtk_toolbar_append_element (GTK_TOOLBAR (toolbar_ed),
                                 GTK_TOOLBAR_CHILD_BUTTON,
                                 NULL,
-                                "Close",
-                                NULL, NULL,
-                                tmp_toolbar_icon, NULL, NULL);
-gtk_widget_show(button_quit_ed);
+                               "Close",
+                               NULL, NULL,
+                               tmp_toolbar_icon, NULL, NULL);
+ gtk_widget_show(button_quit_ed);
+ }
 /* blocks choice hbox */
+if(is_smallscr==1) {
+ hbox31 = gtk_hbox_new(TRUE,0);
+ hbox32 = gtk_hbox_new(TRUE,0);
+ gtk_widget_show(hsep4);
+ }
 hbox_block =gtk_hbox_new(TRUE,0);
 gtk_box_set_homogeneous (GTK_BOX(hbox_block),FALSE);
-label1_block = gtk_label_new("               Block : ");
+if(is_smallscr==0) label1_block = gtk_label_new("               Block : ");
+	else label1_block = gtk_label_new("\n Block : ");
 gtk_widget_show (label1_block);
-gtk_box_pack_start (GTK_BOX (hbox_block), label1_block, FALSE, FALSE, 0);
+
+if(is_smallscr==0) gtk_box_pack_start (GTK_BOX (hbox_block), label1_block, FALSE, FALSE, 0);
+	else {
+		gtk_box_pack_start (GTK_BOX (hbox31), label1_block, FALSE, FALSE, 0);
+		gtk_widget_show(gtk_toolbar_append_element (GTK_TOOLBAR (toolbar_ed),
+                                GTK_TOOLBAR_CHILD_WIDGET,
+                                hbox31,
+                                "",
+                                NULL, NULL,
+                                NULL, NULL, NULL));
+	     }
 button_down= gtk_button_new_from_stock ("gtk-go-down");
 gtk_widget_show(button_down);
 gtk_box_pack_start (GTK_BOX (hbox_block), button_down, FALSE, FALSE, 0);
@@ -360,11 +420,27 @@ gtk_widget_show(gtk_toolbar_append_element (GTK_TOOLBAR (toolbar_ed),
                                 "",
                                 NULL, NULL,
                                 NULL, NULL, NULL));
+
+if (is_smallscr==0) {
 /* A(i,j)= x hbox */
 hbox_aij = gtk_hbox_new(TRUE,0);
+} else {
+/* A(i,j)= vbox */
+hbox_aij = gtk_vbox_new(TRUE,0);
+}
 gtk_box_set_homogeneous (GTK_BOX(hbox_aij),FALSE);
-label_aij=gtk_label_new("   Value : ");
-gtk_box_pack_start (GTK_BOX (hbox_aij), label_aij, FALSE, FALSE, 0);
+if (is_smallscr==0) label_aij=gtk_label_new("   Value : ");
+	else label_aij=gtk_label_new("\n\n   Value : ");
+if(is_smallscr==0) gtk_box_pack_start (GTK_BOX (hbox_aij), label_aij, FALSE, FALSE, 0);
+	else {
+		gtk_box_pack_start (GTK_BOX (hbox32), label_aij, FALSE, FALSE, 0);
+                gtk_widget_show(gtk_toolbar_append_element (GTK_TOOLBAR (toolbar_ed),
+                                GTK_TOOLBAR_CHILD_WIDGET,
+                                hbox32,
+                                "",
+                                NULL, NULL,
+                                NULL, NULL, NULL));
+	    }
 gtk_widget_show (label_aij);
 entry_ij = gtk_entry_new_with_max_length (14);
 gtk_entry_set_width_chars (GTK_ENTRY(entry_ij),15);
@@ -391,10 +467,22 @@ gtk_widget_show(gtk_toolbar_append_element (GTK_TOOLBAR (toolbar_ed),
                                 "",
                                 NULL, NULL,
                                 NULL, NULL, NULL));
+if(is_smallscr==1){
+/* cancel button  last position */
+ tmp_toolbar_icon = gtk_image_new_from_stock ("gtk-quit", gtk_toolbar_get_icon_size (GTK_TOOLBAR (toolbar_ed)));
+ button_quit_ed = gtk_toolbar_append_element (GTK_TOOLBAR (toolbar_ed),
+                                GTK_TOOLBAR_CHILD_BUTTON,
+			        NULL,
+			       "Close",
+			       NULL, NULL,
+			       tmp_toolbar_icon, NULL, NULL);
+ gtk_widget_show(button_quit_ed);
+ }
 
 /* fourth hbox consists in statusbar  */
 /**************** statusbar  begins        */
 statusb_edita = gtk_statusbar_new();
+gtk_statusbar_set_has_resize_grip((GtkStatusbar *)statusb_edita,FALSE);
 gtk_widget_show (statusb_edita);
 gtk_box_pack_end (GTK_BOX (vboxm_edita), statusb_edita, FALSE, FALSE, 0);
 /**************** statusbar ends           */
@@ -995,9 +1083,11 @@ a_labels_update()
 char buf[256];
 sprintf(buf,"  %lg  ",st_def());
 gtk_label_set_text (GTK_LABEL(label_222),buf);
-sprintf(buf,"This Block:  max=%g  min=%g ",matabmax,matabqmin);
+if (is_smallscr==0) sprintf(buf,"This Block:  max=%g  min=%g ",matabmax,matabqmin);
+        else sprintf(buf,"This Block: \n max=%g \n min=%g ",matabmax,matabqmin);
 gtk_label_set_text (GTK_LABEL(label_231),buf);
-sprintf(buf,"All Blocks: max=%g  min=%g ",aamax(),aamin());
+if (is_smallscr==0) sprintf(buf,"All Blocks:  max=%g  min=%g ",aamax(),aamin());
+        else sprintf(buf,"All Blocks: \n max=%g \n min=%g ",aamax(),aamin());
 gtk_label_set_text (GTK_LABEL(label_232) ,buf);
 return(0);
 }
