@@ -6,7 +6,7 @@
  * Largo Pontecorvo 5                                         *
  * 56127 Pisa                                                 *
  * Italy                                                      *
- * Version 1.3 - March 2007                                   *
+ * Version 2.1 - June  2009                                   *
  **************************************************************
  *
  *  edit-b.c - view and edit B0, BN1, B  - both callbacks and interfaces
@@ -39,9 +39,10 @@ create_edit_b_window()
 /* GtkWidget *window_edit_b; global */
 GtkWidget *vboxm_editb;
 GtkWidget *hbox1,*hbox2;
-GtkWidget *vbox1,*vbox2;
+GtkWidget *vbox1,*vbox2,*vbox3;
 GtkWidget *vbox11,*vbox14;
 /* GtkWidget *edit_vbox12b,*edit_vbox13b; globale */
+GtkWidget *hbox31,*hbox32;
 GtkWidget *hsep11,*hsep12,*hsep13; /* separators */
 GtkWidget *label_v11,*label_v12,*label_v13; /* titles for button groups */
 GtkWidget *button_pos_neg;
@@ -54,7 +55,7 @@ GtkWidget *button_range_normal;
 GtkWidget *button_range_adaptive;
 GtkWidget *button_range_block;  
 GSList *range_list = NULL;
-GtkWidget *hsep1,*hsep2,*vsep0,*vsep1,*vsep2; /* separators */
+GtkWidget *hsep1,*hsep2,*hsep3,*hsep4,*vsep0,*vsep1,*vsep2; /* separators */
 GtkWidget *vbox21,*vbox22, *vbox23;
 GtkWidget *label_211,*label_212; /* labels with matrix results */
 GtkWidget *label_221; /* labels with matrix results */
@@ -85,7 +86,9 @@ int nblk;
 /* window_edit_b */
 window_edit_b=gtk_window_new (GTK_WINDOW_TOPLEVEL);
 gtk_window_set_title (GTK_WINDOW (window_edit_b), "View and Edit  Matrix B");
-gtk_window_set_default_size (GTK_WINDOW (window_edit_b), 720, 700);
+if(is_smallscr==0) gtk_window_set_default_size (GTK_WINDOW (window_edit_b), 720, 700);
+	else gtk_window_set_default_size (GTK_WINDOW (window_edit_b), 550, 700);
+gtk_window_set_resizable (GTK_WINDOW (window_edit_b),FALSE);
 b_selected_block = peb.block; /* we need this value here */
 gdk_rgb_init();
 
@@ -212,8 +215,8 @@ gtk_box_pack_start (GTK_BOX (hbox1), vsep0, FALSE, FALSE, 0);
 /* second vbox in first hbox for matrix display */
 vbox2=gtk_vbox_new(FALSE,5);
 gtk_widget_show(vbox2);
-gtk_box_pack_end (GTK_BOX (hbox1), vbox2, FALSE, FALSE, 0);
-gtk_container_set_border_width (GTK_CONTAINER (vbox2), 10);
+gtk_box_pack_start (GTK_BOX (hbox1), vbox2, FALSE, FALSE, 0);
+gtk_container_set_border_width (GTK_CONTAINER (vbox2), 5);
 /* matrix drawable area */
 gtk_widget_push_visual(gdk_rgb_get_visual());
 gtk_widget_push_colormap(gdk_rgb_get_cmap());
@@ -243,13 +246,23 @@ hsep1 = gtk_hseparator_new();
 gtk_widget_show(hsep1);
 gtk_box_pack_start (GTK_BOX (vboxm_editb), hsep1, FALSE, FALSE, 0);
 
+/* is small screen we use a third vbox on the right */
+if (is_smallscr==1) {
+vbox3=gtk_vbox_new(FALSE,5);
+gtk_box_pack_start (GTK_BOX (hbox1), vbox3, TRUE, TRUE, 0);
+gtk_widget_show(vbox3);
+}
+
 /* second hbox contains various data show boxes */
+/* in small screen they in the vbox3 */
 hbox2=gtk_hbox_new(FALSE,5);
 gtk_widget_show(hbox2);
-gtk_box_pack_start (GTK_BOX (vboxm_editb), hbox2, FALSE, FALSE, 0);
+if (is_smallscr==0) gtk_box_pack_start (GTK_BOX (vboxm_editb), hbox2, FALSE, FALSE, 0);
+
 /* matrix #blocks and dimensions */
 vbox21 = gtk_vbox_new(TRUE,5);
-gtk_box_pack_start (GTK_BOX (hbox2), vbox21, TRUE, TRUE, 0);
+if (is_smallscr==0) gtk_box_pack_start (GTK_BOX (hbox2), vbox21, TRUE, TRUE, 0);
+	else gtk_box_pack_start (GTK_BOX (vbox3), vbox21, TRUE, TRUE, 0);
 gtk_widget_show(vbox21);
 /*
  * B consist of B0 matrix, committed.dimension_n x committed.dimension_n,           b_selected_block=0
@@ -276,16 +289,25 @@ label_211 = gtk_label_new(buf);
 gtk_widget_show(label_211); 
 gtk_box_pack_start (GTK_BOX (vbox21), label_211, TRUE, TRUE, 0);
 
-sprintf(buf," [ dimensions  %d and %d  ",committed.dimension_m, committed.dimension_n);
+sprintf(buf," [ dimensions  %d and %d ] ",committed.dimension_m, committed.dimension_n);
 label_212 = gtk_label_new(buf);
 gtk_widget_show(label_212);
 gtk_box_pack_start (GTK_BOX (vbox21), label_212, FALSE, FALSE, 0);
+if (is_smallscr==0) {
 /* vertical separator */
 vsep1 = gtk_vseparator_new();
 gtk_widget_show(vsep1);
 gtk_box_pack_start (GTK_BOX (hbox2), vsep1, FALSE, FALSE, 0);
+ } else {
+/* horizontal separator */
+ hsep3 =gtk_hseparator_new();
+ gtk_widget_show(hsep3);
+ gtk_box_pack_start (GTK_BOX (vbox3), hsep3, FALSE, FALSE, 0);
+ }
+
 vbox22 = gtk_vbox_new(TRUE,0);
-gtk_box_pack_start (GTK_BOX (hbox2), vbox22, TRUE, TRUE, 0);
+if(is_smallscr==0) gtk_box_pack_start (GTK_BOX (hbox2), vbox22, TRUE, TRUE, 0);
+	else gtk_box_pack_start (GTK_BOX (vbox3), vbox22, TRUE, TRUE, 0);
 gtk_widget_show(vbox22);
 sprintf(buf,"Global Stochasticity Defect");
 label_221 = gtk_label_new(buf);
@@ -295,12 +317,21 @@ sprintf(buf,"  %lg  ",st_def_b(committed.type));
 label_222b = gtk_label_new(buf);
 gtk_widget_show(label_222b);
 gtk_box_pack_start (GTK_BOX (vbox22), label_222b, TRUE, TRUE, 0);
+if (is_smallscr==0) {
 /* vertical separator */
 vsep2 = gtk_vseparator_new();
 gtk_widget_show(vsep2);
 gtk_box_pack_start (GTK_BOX (hbox2), vsep2, FALSE, FALSE, 0);
+ } else {
+/* horizontal separator */
+ hsep4 =gtk_hseparator_new();
+ gtk_widget_show(hsep4);
+ gtk_box_pack_start (GTK_BOX (vbox3), hsep4, FALSE, FALSE, 0);
+ }
+
 vbox23 = gtk_vbox_new(TRUE,0);
-gtk_box_pack_start (GTK_BOX (hbox2), vbox23, TRUE, TRUE, 0);
+if (is_smallscr==0) gtk_box_pack_start (GTK_BOX (hbox2), vbox23, TRUE, TRUE, 0);
+	else gtk_box_pack_start (GTK_BOX (vbox3), vbox23, TRUE, TRUE, 0);
 gtk_widget_show(vbox23);
 label_231b = gtk_label_new(" ");
 gtk_widget_show(label_231b);
@@ -309,18 +340,29 @@ label_232b = gtk_label_new(" ");
 gtk_widget_show(label_232b);
 gtk_box_pack_start (GTK_BOX (vbox23), label_232b, TRUE, TRUE, 0);
 
+if(is_smallscr==0){
 /* horizontal separator */
 hsep2 = gtk_hseparator_new();
 gtk_widget_show(hsep2);
 gtk_box_pack_start (GTK_BOX (vboxm_editb), hsep2, FALSE, FALSE, 0);
+} else {
+/* horizontal separator */
+ hsep2 = gtk_hseparator_new();
+ gtk_widget_show(hsep2);
+ gtk_box_pack_start (GTK_BOX (vbox3), hsep2, FALSE, FALSE, 0);
+}
 
 /* third hbox consists in toolbox  */
 /* toolbar begins */
 toolbar_ed = gtk_toolbar_new ();
+if (is_smallscr==1)
+gtk_toolbar_set_orientation(GTK_TOOLBAR (toolbar_ed),GTK_ORIENTATION_VERTICAL);
 gtk_widget_show (toolbar_ed);
-gtk_box_pack_start (GTK_BOX (vboxm_editb), toolbar_ed, FALSE, FALSE, 0);
-gtk_container_set_border_width (GTK_CONTAINER (toolbar_ed), 10);
+if(is_smallscr==0) gtk_box_pack_start (GTK_BOX (vboxm_editb), toolbar_ed, FALSE, FALSE, 0);
+	else gtk_box_pack_start (GTK_BOX (vbox3), toolbar_ed, FALSE, FALSE, 0);
+gtk_container_set_border_width (GTK_CONTAINER (toolbar_ed), 5);
 gtk_toolbar_set_style (GTK_TOOLBAR (toolbar_ed), GTK_TOOLBAR_BOTH);
+if(is_smallscr==0){
 /* cancel button  first position */
 tmp_toolbar_icon = gtk_image_new_from_stock ("gtk-quit", gtk_toolbar_get_icon_size (GTK_TOOLBAR (toolbar_ed)));
 button_quit_ed = gtk_toolbar_append_element (GTK_TOOLBAR (toolbar_ed),
@@ -329,13 +371,30 @@ button_quit_ed = gtk_toolbar_append_element (GTK_TOOLBAR (toolbar_ed),
                                 "Close",
                                 NULL, NULL,
                                 tmp_toolbar_icon, NULL, NULL);
-gtk_widget_show(button_quit_ed);
+ gtk_widget_show(button_quit_ed);
+ }
 /* blocks choice hbox */
+if(is_smallscr==1) {
+ hbox31 = gtk_hbox_new(TRUE,0);
+ hbox32 = gtk_hbox_new(TRUE,0);
+ gtk_widget_show(hsep4);
+ }
 hbox_block =gtk_hbox_new(TRUE,0);
 gtk_box_set_homogeneous (GTK_BOX(hbox_block),FALSE);
-label1_block = gtk_label_new("               Block : ");
+if(is_smallscr==0) label1_block = gtk_label_new("               Block : ");
+	 else label1_block = gtk_label_new("\n Block : ");
 gtk_widget_show (label1_block);
-gtk_box_pack_start (GTK_BOX (hbox_block), label1_block, FALSE, FALSE, 0);
+
+if(is_smallscr==0)  gtk_box_pack_start (GTK_BOX (hbox_block), label1_block, FALSE, FALSE, 0);
+        else {
+                gtk_box_pack_start (GTK_BOX (hbox31), label1_block, FALSE, FALSE, 0);
+                gtk_widget_show(gtk_toolbar_append_element (GTK_TOOLBAR (toolbar_ed),
+                                GTK_TOOLBAR_CHILD_WIDGET,
+                                hbox31,
+                                "",
+                                NULL, NULL,
+                                NULL, NULL, NULL));
+             }
 button_down= gtk_button_new_from_stock ("gtk-go-down");
 gtk_widget_show(button_down);
 gtk_box_pack_start (GTK_BOX (hbox_block), button_down, FALSE, FALSE, 0);
@@ -357,11 +416,26 @@ gtk_widget_show(gtk_toolbar_append_element (GTK_TOOLBAR (toolbar_ed),
                                 "",
                                 NULL, NULL,
                                 NULL, NULL, NULL));
+if (is_smallscr==0) {
 /* A(i,j)= x hbox */
 hbox_aij = gtk_hbox_new(TRUE,0);
+} else {
+/* A(i,j)= vbox */
+hbox_aij = gtk_vbox_new(TRUE,0);
+}
 gtk_box_set_homogeneous (GTK_BOX(hbox_aij),FALSE);
-label_aij=gtk_label_new("   Value : ");
-gtk_box_pack_start (GTK_BOX (hbox_aij), label_aij, FALSE, FALSE, 0);
+if (is_smallscr==0) label_aij=gtk_label_new("   Value : ");
+ else label_aij=gtk_label_new("\n\n   Value : ");
+if(is_smallscr==0)  gtk_box_pack_start (GTK_BOX (hbox_aij), label_aij, FALSE, FALSE, 0);
+        else {
+                gtk_box_pack_start (GTK_BOX (hbox32), label_aij, FALSE, FALSE, 0);
+                gtk_widget_show(gtk_toolbar_append_element (GTK_TOOLBAR (toolbar_ed),
+                                GTK_TOOLBAR_CHILD_WIDGET,
+                                hbox32,
+                                "",
+                                NULL, NULL,
+                                NULL, NULL, NULL));
+            }
 gtk_widget_show (label_aij);
 entryb_ij = gtk_entry_new_with_max_length (14);
 gtk_entry_set_width_chars (GTK_ENTRY(entryb_ij),15);
@@ -389,9 +463,22 @@ gtk_widget_show(gtk_toolbar_append_element (GTK_TOOLBAR (toolbar_ed),
                                 NULL, NULL,
                                 NULL, NULL, NULL));
 
+if(is_smallscr==1){
+/* cancel button  last position */
+ tmp_toolbar_icon = gtk_image_new_from_stock ("gtk-quit", gtk_toolbar_get_icon_size (GTK_TOOLBAR (toolbar_ed)));
+ button_quit_ed = gtk_toolbar_append_element (GTK_TOOLBAR (toolbar_ed),
+                                GTK_TOOLBAR_CHILD_BUTTON,
+                                NULL,
+                               "Close",
+                               NULL, NULL,
+                               tmp_toolbar_icon, NULL, NULL);
+ gtk_widget_show(button_quit_ed);
+ }
+
 /* fourth hbox consists in statusbar  */
 /**************** statusbar  begins        */
 statusb_editb = gtk_statusbar_new();
+gtk_statusbar_set_has_resize_grip(statusb_editb,FALSE);
 gtk_widget_show (statusb_editb);
 gtk_box_pack_end (GTK_BOX (vboxm_editb), statusb_editb, FALSE, FALSE, 0);
 /**************** statusbar ends           */
@@ -1076,9 +1163,11 @@ b_labels_update()
 char buf[256];
 sprintf(buf,"  %lg  ",st_def_b(committed.type));
 gtk_label_set_text (GTK_LABEL(label_222b),buf);
-sprintf(buf,"This Block:  %d  x  %d   ",b_dim_m,b_dim_n);
+if (is_smallscr==0) sprintf(buf,"This Block:  %d  x  %d   ",b_dim_m,b_dim_n);
+	else sprintf(buf,"This Block:\n  %d  x  %d   ",b_dim_m,b_dim_n);
 gtk_label_set_text (GTK_LABEL(label_231b),buf);
-sprintf(buf," max=%g  min=%g ",matbbmax,matbbqmin);
+if (is_smallscr==0) sprintf(buf," max=%g  min=%g ",matbbmax,matbbqmin);
+	else sprintf(buf," max=%g \n min=%g ",matbbmax,matbbqmin);
 gtk_label_set_text (GTK_LABEL(label_232b) ,buf);
 return(0);
 }
