@@ -6,7 +6,7 @@
  * Largo Pontecorvo 5                                         *
  * 56127 Pisa                                                 *
  * Italy                                                      *
- * Version 1.3 - March 2007                                   *
+ * Version 2.1 - June  2009                                   *
  **************************************************************
  *
  *  examples.c  
@@ -28,6 +28,7 @@
 void
 init_examples(void)
 {
+if(is_debug==1) printf("init_examples: begins\n");
 examples_no=8;  /* number of examples to appear in main menu Examples - min 1 max 9 */
 
 es[1].num=1;
@@ -228,4 +229,5 @@ es[8].alpha=0;
 es[8].is_beta=0;
 es[8].beta=0;
 
+if(is_debug==1) printf("init_examples: ends\n");
 }
