@@ -6,7 +6,7 @@
  * Largo Pontecorvo 5                                         *
  * 56127 Pisa                                                 *
  * Italy                                                      *
- * Version 1.3 - March 2007                                   *
+ * Version 2.1 - June  2009                                   *
  **************************************************************
  *
  *  examples.h  
@@ -21,6 +21,8 @@ void init_examples(void);
 /* globals */
 int selected_es;
 int examples_no; /* =9= number of possible examples 1..9 */
+int is_debug;
 
 struct  examples_str es[10];
 
+/*********************************************/
