@@ -6,12 +6,14 @@
 !  Largo Pontecorvo 5                                         !
 !  56127 Pisa                                                 !
 !  Italy                                                      !
-!  Version 1.3 - March 2007                                   !
+!  Version 2.1 - June  2009                                   !
 !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 !  examplesf.f90                                              !
 !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 
 ! setup input arrays for every Example Problem
+! to be called from callbacks.c only
+!
 subroutine examples_setup (num, m, n, qa, qb, stat,alpha, beta )
 use ponte_f_f
 ! logical debug global 
@@ -22,12 +24,12 @@ integer n     !array second dimension
 integer qa     !Aq mxn arrays
 integer qb    !Bqb mxn arrays 0= no Bqb arrays
 integer stat  !status output 0=ok, else =no memory 
-real(dpr) :: alpha,beta ! optional parameter for some examples
+real(dp) :: alpha,beta ! optional parameter for some examples
 !
 integer i,j,h
-real(dpr) s
-real(dpr),allocatable,dimension(:)::v
-real(dpr):: binomial
+real(dp) s
+real(dp),allocatable,dimension(:)::v
+real(dp):: binomial
 
 if (debug) write(*,*) "examples_setup: entering with num=",num," m=",m," n=",n," qa=",qa," qb=",qb," alpha=",alpha," beta=",beta
 
