@@ -6,7 +6,7 @@
 !  Largo Pontecorvo 5                                         !
 !  56127 Pisa                                                 !
 !  Italy                                                      !
-!  Version 1.3 - March 2007                                   !
+!  Version 2.1 - June  2009                                   !
 !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 !   futils.f90   utility fortran functions to be called by C  !
 !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
@@ -16,7 +16,7 @@
 subroutine getfdrift(x)
 use ponte_f_f
 implicit none
-real(dpr)  x
+real(dp)  x
 x=fdrift
 end subroutine getfdrift
 !
@@ -45,7 +45,7 @@ end subroutine alloc_matA
 subroutine read_matA(n,m,qa,x)
 use ponte_f_f
 implicit none
-real(dpr) :: x
+real(dp) :: x
 integer n,m,qa
 x=A(n,m,qa)
 end subroutine read_matA
@@ -57,7 +57,7 @@ end subroutine read_matA
 subroutine write_matA(n,m,qa,x)
 use ponte_f_f
 implicit none
-real(dpr) :: x
+real(dp) :: x
 integer n,m,qa
 A(n,m,qa)=x
 end subroutine write_matA
@@ -109,7 +109,7 @@ end subroutine alloc_matB
 subroutine read_matB(n,m,qb,x)
 use ponte_f_f
 implicit none
-real(dpr) :: x
+real(dp) :: x
 integer n,m,qb
 x=B(n,m,qb)
 end subroutine read_matB
@@ -121,7 +121,7 @@ end subroutine read_matB
 subroutine write_matB(n,m,qb,x)
 use ponte_f_f
 implicit none
-real(dpr) :: x
+real(dp) :: x
 integer n,m,qb
 B(n,m,qb)=x
 end subroutine write_matB
@@ -167,7 +167,7 @@ end subroutine alloc_matB0
 subroutine read_matB0(n,m,x)
 use ponte_f_f
 implicit none
-real(dpr) :: x
+real(dp) :: x
 integer n,m
 x=B0(n,m)
 end subroutine read_matB0
@@ -178,7 +178,7 @@ end subroutine read_matB0
 subroutine write_matB0(n,m,x)
 use ponte_f_f
 implicit none
-real(dpr) :: x
+real(dp) :: x
 integer n,m
 B0(n,m)=x
 end subroutine write_matB0
@@ -223,7 +223,7 @@ end subroutine alloc_matBN1
 subroutine read_matBN1(n,m,x)
 use ponte_f_f
 implicit none
-real(dpr) :: x
+real(dp) :: x
 integer n,m
 x=BN1(n,m)
 end subroutine read_matBN1
@@ -234,7 +234,7 @@ end subroutine read_matBN1
 subroutine write_matBN1(n,m,x)
 use ponte_f_f
 implicit none
-real(dpr) :: x
+real(dp) :: x
 integer n,m
 BN1(n,m)=x
 end subroutine write_matBN1
@@ -276,7 +276,7 @@ end subroutine alloc_matG
 subroutine read_matG(n,m,x)
 use ponte_f_f
 implicit none
-real(dpr) :: x
+real(dp) :: x
 integer n,m
 x=G(n,m)
 end subroutine read_matG
@@ -287,7 +287,7 @@ end subroutine read_matG
 subroutine write_matG(n,m,x)
 use ponte_f_f
 implicit none
-real(dpr) :: x
+real(dp) :: x
 integer n,m
 G(n,m)=x
 end subroutine write_matG
@@ -329,7 +329,7 @@ end subroutine alloc_matR
 subroutine read_matR(n,m,x)
 use ponte_f_f
 implicit none
-real(dpr) :: x
+real(dp) :: x
 integer n,m
 x=R(n,m)
 end subroutine read_matR
@@ -340,7 +340,7 @@ end subroutine read_matR
 subroutine write_matR(n,m,x)
 use ponte_f_f
 implicit none
-real(dpr) :: x
+real(dp) :: x
 integer n,m
 R(n,m)=x
 end subroutine write_matR
@@ -382,7 +382,7 @@ end subroutine alloc_matU
 subroutine read_matU(n,m,x)
 use ponte_f_f
 implicit none
-real(dpr) :: x
+real(dp) :: x
 integer n,m
 x=U(n,m)
 end subroutine read_matU
@@ -393,7 +393,7 @@ end subroutine read_matU
 subroutine write_matU(n,m,x)
 use ponte_f_f
 implicit none
-real(dpr) :: x
+real(dp) :: x
 integer n,m
 U(n,m)=x
 end subroutine write_matU
@@ -435,7 +435,7 @@ end subroutine alloc_matX0
 subroutine read_matX0(n,m,x)
 use ponte_f_f
 implicit none
-real(dpr) :: x
+real(dp) :: x
 integer n,m
 x=X0(n,m)
 end subroutine read_matX0
@@ -446,7 +446,7 @@ end subroutine read_matX0
 subroutine write_matX0(n,m,x)
 use ponte_f_f
 implicit none
-real(dpr) :: x
+real(dp) :: x
 integer n,m
 X0(n,m)=x
 end subroutine write_matX0
@@ -471,6 +471,59 @@ md=size(X0,2)
  end do
 end subroutine dump_matX0
 
+!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+
+subroutine alloc_matEV(m,stat)
+use ponte_f_f
+implicit none
+integer m,stat
+if (allocated(EV)) deallocate(EV)
+allocate(EV(m,m),STAT=stat)
+EV=0.0d0
+end subroutine alloc_matEV
+
+!
+! to read the content of EV from C routines
+!
+subroutine read_matEV(n,m,x)
+use ponte_f_f
+implicit none
+real(dp) :: x
+integer n,m
+x=EV(n,m)
+end subroutine read_matEV
+
+!
+! to write to EV from C routines
+!
+subroutine write_matEV(n,m,x)
+use ponte_f_f
+implicit none
+real(dp) :: x
+integer n,m
+EV(n,m)=x
+end subroutine write_matEV
+
+!
+! test program
+! dumps EV to Main Window NotePad
+!
+subroutine dump_matEV()
+use ponte_f_f
+implicit none
+integer n,m,nd,md
+! reads dimension nd,md of EV
+nd=size(EV,1)
+md=size(EV,2)
+! writes all the matrix to notePad
+ do m=1,md
+   do n=1,nd
+   write(wout,*)"EV(",n,m,")=",EV(n,m)
+   call print_it_
+   end do
+ end do
+end subroutine dump_matEV
+
 !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 !
 subroutine alloc_matPi0(m,stat)
@@ -488,7 +541,7 @@ end subroutine alloc_matPi0
 subroutine read_matPi0(n,x)
 use ponte_f_f
 implicit none
-real(dpr) :: x
+real(dp) :: x
 integer n
 x=Pi0(n)
 end subroutine read_matPi0
@@ -499,7 +552,7 @@ end subroutine read_matPi0
 subroutine write_matPi0(n,x)
 use ponte_f_f
 implicit none
-real(dpr) :: x
+real(dp) :: x
 integer n
 Pi0(n)=x
 end subroutine write_matPi0
@@ -538,7 +591,7 @@ end subroutine alloc_matPi
 subroutine read_matPi(n,m,x)
 use ponte_f_f
 implicit none
-real(dpr) :: x
+real(dp) :: x
 integer n,m
 x=Pi(n,m)
 end subroutine read_matPi
@@ -549,7 +602,7 @@ end subroutine read_matPi
 subroutine write_matPi(n,m,x)
 use ponte_f_f
 implicit none
-real(dpr) :: x
+real(dp) :: x
 integer n,m
 Pi(n,m)=x
 end subroutine write_matPi
@@ -631,7 +684,7 @@ subroutine normalize_matA
 use ponte_f_f
 implicit none
 integer nd,md,j
-real(dpr) :: ss
+real(dp) :: ss
 nd=size(A,1)
 md=size(A,2)
 
@@ -644,3 +697,87 @@ end do
 
 endif
 end subroutine normalize_matA
+
+!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+!
+! compute spectral radius of matrix G,R,U
+! quick&dirty hack - to be changed
+!
+subroutine sprad_g(x,stat,t)
+use ponte_f_f
+implicit none
+real(dp) :: x
+integer m,n,i,stat,nn,t
+real(dp) :: v1,v2,w
+real(dp),dimension(:,:),allocatable:: WW
+!t=0 impossibile, t=1 G, t=2 R, t=3 U, t=4 ev
+
+select case (t)
+case(1) 
+     m=size(G,1)
+case(2)
+     m=size(R,1)
+case(3)
+     m=size(U,1)
+case(4)
+     m=size(EV,1)
+case default
+     x=-1
+     return
+end select
+if (allocated(WW)) deallocate(WW)
+allocate(WW(m,m),STAT=stat)
+select case (t)
+case(1)
+     WW=G
+case(2)
+     WW=R
+case(3)
+     WW=U
+case(4)
+     WW=EV
+case default
+end select
+nn=50
+x=-1.0d0
+n=1
+i=0
+
+v1=maxval(WW)
+if (v1 == 0.0d0) return
+WW=WW/v1
+w=log(v1)
+if ( debug ) write(*,*) v1
+
+10 continue
+i=i+1
+if (i > nn) return
+WW=matmul(WW,WW)
+v2=v1
+v1=maxval(WW)
+if ( debug ) write(*,*) v1
+if (v1 == 0.0d0) return
+WW=WW/v1
+n=n*2
+w=w+log(v1)/n
+if(abs(v1-v2)/v1 > 1.0d-15) goto 10
+w=w+log(v1)/n
+x=exp(w)
+
+end subroutine sprad_g
+
+!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+!
+! set or unset debug fortran variable
+!
+subroutine ssdebug(t)
+use ponte_f_f, only: debug
+implicit none
+integer t
+select case(t)
+case(0)
+    debug=.false.
+case default
+    debug=.true.
+end select
+end subroutine ssdebug
