@@ -6,7 +6,7 @@
  * Largo Pontecorvo 5                                         *
  * 56127 Pisa                                                 *
  * Italy                                                      *
- * Version 1.3 - March 2007                                   *
+ * Version 2.1 - June  2009                                   *
  **************************************************************
  *
  *  help.c  - about and  help window interfaces and callbacks
@@ -45,7 +45,7 @@ create_window_about (void)
   gtk_frame_set_shadow_type (GTK_FRAME(frame),GTK_SHADOW_ETCHED_IN);
   gtk_widget_show(frame);
   gtk_container_add(GTK_CONTAINER(dialog_vbox),frame); 
-  label = gtk_label_new("\n\nStructured Markov Chains Solver\n\nDario Bini, Beatrice Meini, Sergio Steffe\'\n\nDipartimento di Matematica \"Leonida Tonelli\"\nUniversita\' di Pisa, Pisa, Italy\n {bini, meini, steffe}@dm.unipi.it\n\nVersion 1.3 March 2007\n\n");
+  label = gtk_label_new("\n\nStructured Markov Chains Solver\n\nDario Bini, Beatrice Meini, Sergio Steffe\'\n\nDipartimento di Matematica \"Leonida Tonelli\"\nUniversita\' di Pisa, Pisa, Italy\n {bini, meini, steffe}@dm.unipi.it\n\nVersion 2.1  June 2009\n\n");
   gtk_widget_show(label);
   gtk_container_add(GTK_CONTAINER(frame),label);
   
@@ -96,8 +96,8 @@ create_window_help (void)
   gtk_window_set_title (GTK_WINDOW (help_window),"Structured Markov Chains Solver Help");
 
   gtk_window_set_position (GTK_WINDOW (help_window), GTK_WIN_POS_MOUSE);
-  gtk_window_set_default_size (GTK_WINDOW (help_window), 780,640);
-
+  if(is_smallscr==0) gtk_window_set_default_size (GTK_WINDOW (help_window), 780,640);
+	else gtk_window_set_default_size (GTK_WINDOW (help_window), 700,400);
   dialog_vbox = GTK_DIALOG (help_window)->vbox;
   gtk_widget_show (dialog_vbox);
   sections_hbox = gtk_hbox_new(FALSE,0);
@@ -217,6 +217,11 @@ gtk_text_buffer_get_end_iter(bufferm,&enditerm);
 gtk_text_buffer_insert(bufferm,&enditerm,docu13,-1);
 gtk_text_buffer_get_end_iter(bufferm,&enditerm);
 gtk_text_buffer_insert(bufferm,&enditerm,docu14,-1);
+gtk_text_buffer_get_end_iter(bufferm,&enditerm);
+gtk_text_buffer_insert(bufferm,&enditerm,docu15,-1);
+gtk_text_buffer_get_end_iter(bufferm,&enditerm);
+gtk_text_buffer_insert(bufferm,&enditerm,docu16,-1);
+
 }
 /*********************************/
 
@@ -466,6 +471,8 @@ gtk_text_buffer_get_end_iter(bufferm,&enditerm);
 gtk_text_buffer_insert(bufferm,&enditerm,docu118,-1);
 gtk_text_buffer_get_end_iter(bufferm,&enditerm);
 gtk_text_buffer_insert(bufferm,&enditerm,docu119,-1);
+gtk_text_buffer_get_end_iter(bufferm,&enditerm);
+gtk_text_buffer_insert(bufferm,&enditerm,docu120,-1);
 
 
 }
@@ -475,9 +482,7 @@ gtk_text_buffer_insert(bufferm,&enditerm,docu119,-1);
 void on_help_credits_clicked  (GtkButton       *button, gpointer         user_data)
 {
 GtkTextIter  enditerm;
-gtk_text_buffer_set_text(bufferm,docu120,-1);
-gtk_text_buffer_get_end_iter(bufferm,&enditerm);
-gtk_text_buffer_insert(bufferm,&enditerm,docu121,-1);
+gtk_text_buffer_set_text(bufferm,docu121,-1);
 gtk_text_buffer_get_end_iter(bufferm,&enditerm);
 gtk_text_buffer_insert(bufferm,&enditerm,docu122,-1);
 gtk_text_buffer_get_end_iter(bufferm,&enditerm);
@@ -494,6 +499,8 @@ gtk_text_buffer_get_end_iter(bufferm,&enditerm);
 gtk_text_buffer_insert(bufferm,&enditerm,docu128,-1);
 gtk_text_buffer_get_end_iter(bufferm,&enditerm);
 gtk_text_buffer_insert(bufferm,&enditerm,docu129,-1);
+gtk_text_buffer_get_end_iter(bufferm,&enditerm);
+gtk_text_buffer_insert(bufferm,&enditerm,docu130,-1);
 
 
 }
@@ -503,9 +510,9 @@ gtk_text_buffer_insert(bufferm,&enditerm,docu129,-1);
 void on_help_thanks_clicked  (GtkButton       *button, gpointer         user_data)
 {
 GtkTextIter  enditerm;
-gtk_text_buffer_set_text(bufferm,docu130,-1);
+gtk_text_buffer_set_text(bufferm,docu131,-1);
 gtk_text_buffer_get_end_iter(bufferm,&enditerm);
-gtk_text_buffer_insert(bufferm,&enditerm,docu131,-1);
+gtk_text_buffer_insert(bufferm,&enditerm,docu132,-1);
 
 
 }
