@@ -6,7 +6,7 @@
  * Largo Pontecorvo 5                                         *
  * 56127 Pisa                                                 *
  * Italy                                                      *
- * Version 1.3 - March 2007                                   *
+ * Version 2.1 - June  2009                                   *
  **************************************************************
  *
  *  help.h  - about and  help
@@ -39,3 +39,6 @@ void on_about_destroy_activate   (GtkWidget *, gpointer );
 /* globals help.c */
 GtkTextBuffer *bufferm;
 
+/*globals main.c */
+int is_smallscr;
+/*********************************************/
