@@ -6,7 +6,7 @@
  * Largo Pontecorvo 5                                         *
  * 56127 Pisa                                                 *
  * Italy                                                      *
- * Version 1.3 - March 2007                                   *
+ * Version 2.1 - June  2009                                   *
  **************************************************************
  *
  *  main.c
@@ -32,28 +32,43 @@ main (int argc, char *argv[])
 #endif
 {
 char c;
+int  leggirc;
 /* debug and help flags */
-if ((argc > 2) ) { usage(argv[0]); return(-1); };
+is_debug=0;
+is_smallscr=0;
+leggirc=0; /* default no */
+if ((argc > 4) ) { usage(argv[0]); return(-1); };
 /* getopt */
-while ((c = getopt (argc, argv, "hdv")) != -1)
+while ((c = getopt (argc, argv, "hdvsr")) != -1)
 switch (c)
            {
             case 'h': /*help*/
                 printf("\nSMCSolver:");
                 printf("  STRUCTURED MARKOV CHAINS SOLVER\n"); 
-                printf("            Dario Bini, Beatrice Meini, Sergio Steffe\'\n");
-	        printf("            Dipartimento di Matematica \"Leonida Tonelli\"\n");
-                printf("            Universita\' di Pisa, Pisa     Italy\n\n");
-                printf("            bini,meini,steffe @dm.unipi.it\n\n");
+                printf("         Dario Bini, Beatrice Meini, Sergio Steffe\'\n");
+	        printf("         Dipartimento di Matematica \"Leonida Tonelli\"\n");
+                printf("         Universita\' di Pisa, Pisa     Italy\n\n");
+                printf("         bini,meini,steffe @dm.unipi.it\n\n");
+		printf("         optional flags:   -v (version)  -d (debug)  -s (small screen) -r (reads .SMCSolverrc) -h (this help)\n\n");
                 return(0);
             case 'v': /*version*/
-                printf("\nSMCSolver:  Version 1.3   March 2007\n\n");
+                printf("\nSMCSolver:  Version 2.1   June  2009\n\n");
                 return(0);
             case 'd': /*debug*/
                 is_debug=1;    /* 1= debugging output active on console 0=normal */
 		break; 
+	    case 's': /*small screen size*/
+		is_smallscr=1;
+		break;
+	    case 'r': /*read .SMCSolverrc */
+		leggirc=1;
+		break;
+	    case '?': /* invalid option */
+		usage(argv[0]);
+		return(0);
             default:
 		is_debug=0;
+		leggirc=0;
 	  }
 /* first of all: who am I ?  for later use ... */
 gethostname(my_host_name, 512);
@@ -64,14 +79,19 @@ gtk_set_locale ();
 init_examples();
 /* load algorithms parameters */
 parameters_setup();
+
 /* initialize gtk, gdk, treads */
 g_thread_init (NULL);
 gdk_threads_init ();
 gtk_init( &argc, &argv );
 /* printf("%s\n",gtk_set_locale ());*/
+if (leggirc==1) gtk_rc_parse(".SMCSolverrc" );
 /* open main window  */
+
 window_main = (GtkWidget*) create_window_main();
+gtk_window_unmaximize ((GtkWindow*)window_main); /* do not maximize window as default */
 gtk_widget_show (window_main);
+
 gdk_threads_enter ();
 gtk_main ();
 gdk_threads_leave ();
@@ -85,7 +105,10 @@ static void usage(char *command)
         fprintf(stderr,
 "Usage: %s  [OPTION]... \n"
 "-h            help\n"
+"-v            version\n"
 "-d            debugging\n"
+"-s            small screen setup\n"
+"-r            reads .SMCSolverrc\n"
          ,command);
 }
 /*********************************/
