@@ -6,7 +6,7 @@
  * Largo Pontecorvo 5                                         *
  * 56127 Pisa                                                 *
  * Italy                                                      *
- * Version 1.3 - March 2007                                   *
+ * Version 2.1 - June  2009                                   *
  **************************************************************
  *
  *  main.h  
@@ -26,9 +26,10 @@ void parameters_setup(void);
 
 /* globals */
 int is_debug;
+int is_smallscr;
 char my_host_name[512];       /* hostname, used by various outputs */
 char my_prog_name[512];       /* program name, used by various outputs */
 GtkWidget *window_main;       /* main window */
-struct parameters_str max[4],min[4],deflt[4],choice[4]; /* default parametres for each algorithm */
-
+struct parameters_str max[6],min[6],deflt[6],choice[6]; /* default parametres for each algorithm */
 
+/*********************************************/
