@@ -6,7 +6,7 @@
  * Largo Pontecorvo 5                                         *
  * 56127 Pisa                                                 *
  * Italy                                                      *
- * Version 1.3 - March 2007                                   *
+ * Version 2.1 - June  2009                                   *
  **************************************************************
  *
  *  padwrite.c -  writing asyncronously on the NotePad of the Main Window and keep situation bar up to date .
@@ -101,7 +101,7 @@ gint
 selection_uptodaten(void)
 {
 /* GtkWidget *handlebox_s; global */
-/* GtkWidget *label_s1, *label_s2, *label_s3, *label_s4; globals */
+/* GtkWidget *label_s1, *label_s2, *label_s3, *label_s4, *label_s5, *label_s6; globals */
 /* algorithms_choice; global */
 /* "PROBLEM                DATA                       ALGORITHM                       GOAL" */
 int k;
@@ -109,9 +109,27 @@ char tmp[256];
  k=0;
  if (committed.allocated ==1) {
    switch (committed.type){
-        case 1: gtk_label_set_text (GTK_LABEL(label_s1),"QBD"); k=1; break;
-        case 2: gtk_label_set_text (GTK_LABEL(label_s1),"M/G/1"); k=2; break;
-        case 3: gtk_label_set_text (GTK_LABEL(label_s1),"GI/M/1"); k=3; break;
+        case 1: 
+		gtk_label_set_text (GTK_LABEL(label_s1),"QBD"); 
+		k=1; 
+		gtk_widget_set_sensitive (menuitem_qbd,TRUE);
+		gtk_widget_set_sensitive (menuitem_mg1,FALSE);
+		gtk_widget_set_sensitive (menuitem_gim1,FALSE);
+		break;
+        case 2: 
+		gtk_label_set_text (GTK_LABEL(label_s1),"M/G/1"); 
+		k=2; 
+		gtk_widget_set_sensitive (menuitem_qbd,FALSE);
+                gtk_widget_set_sensitive (menuitem_mg1,TRUE);
+                gtk_widget_set_sensitive (menuitem_gim1,FALSE);
+		break;
+        case 3: 
+		gtk_label_set_text (GTK_LABEL(label_s1),"GI/M/1"); 
+		k=3; 
+		gtk_widget_set_sensitive (menuitem_qbd,FALSE);
+                gtk_widget_set_sensitive (menuitem_mg1,FALSE);
+                gtk_widget_set_sensitive (menuitem_gim1,TRUE);
+		break;
         default:gtk_label_set_text (GTK_LABEL(label_s1),"Unknown");
         }
    if (committed.example !=0) {sprintf(tmp,"Example %d",committed.example);gtk_label_set_text (GTK_LABEL(label_s2),tmp); }
@@ -127,45 +145,58 @@ char tmp[256];
 
  switch (algorithms_choice.type){
         case 1: if( algorithms_choice.cr_base==1) gtk_label_set_text (GTK_LABEL(label_s3),"Cyclic Reduction(basic)");
-                if( algorithms_choice.cr_shift==1) gtk_label_set_text (GTK_LABEL(label_s3),"Cyclic Reduction(shift)");
                 if( algorithms_choice.cr_diag==1) gtk_label_set_text (GTK_LABEL(label_s3),"Cyclic Reduction(diag.adj.)");
                 break;
         case 2: if( algorithms_choice.lr_base==1) gtk_label_set_text (GTK_LABEL(label_s3),"Logarithmic Reduction(basic)");
-                if( algorithms_choice.lr_shift==1) gtk_label_set_text (GTK_LABEL(label_s3),"Logarithmic Reduction(shift)");
                 if( algorithms_choice.lr_gth==1) gtk_label_set_text (GTK_LABEL(label_s3),"Logarithmic Reduction(diag.adj.)");
                 break;
-        case 3: if((algorithms_choice.fi_base0==1)&&(algorithms_choice.fi_natural==1))gtk_label_set_text (GTK_LABEL(label_s3),"Functional Iteration(natural,basic,x(0)=0)");
-                if((algorithms_choice.fi_base0==1)&&(algorithms_choice.fi_traditional==1))gtk_label_set_text (GTK_LABEL(label_s3),"Functional Iteration(traditional,basic,x(0)=0)");
-                if((algorithms_choice.fi_base0==1)&&(algorithms_choice.fi_Ubased==1))gtk_label_set_text (GTK_LABEL(label_s3),"Functional Iteration(U-based,basic,x(0)=0)");
-                if((algorithms_choice.fi_base1==1)&&(algorithms_choice.fi_natural==1)) gtk_label_set_text (GTK_LABEL(label_s3),"Functional Iteration(natural,basic,x(0)=I)");
-                if((algorithms_choice.fi_base1==1)&&(algorithms_choice.fi_traditional==1)) gtk_label_set_text (GTK_LABEL(label_s3),"Functional Iteration(traditional,basic,x(0)=I)");
-                if((algorithms_choice.fi_base1==1)&&(algorithms_choice.fi_Ubased==1)) gtk_label_set_text (GTK_LABEL(label_s3),"Functional Iteration(U-based,basic,x(0)=I)");
-
-
-
-                if((algorithms_choice.fi_base_u==1)&&(algorithms_choice.fi_natural==1)) gtk_label_set_text (GTK_LABEL(label_s3),"Functional Iteration(natural,basic,x user)");
-                if((algorithms_choice.fi_base_u==1)&&(algorithms_choice.fi_traditional==1)) gtk_label_set_text (GTK_LABEL(label_s3),"Functional Iteration(traditional,basic,x user)");
-                if((algorithms_choice.fi_base_u==1)&&(algorithms_choice.fi_Ubased==1)) gtk_label_set_text (GTK_LABEL(label_s3),"Functional Iteration(U-based,basic,x user)");
-
-
-
-                if((algorithms_choice.fi_shift==1)&&(algorithms_choice.fi_natural==1)) gtk_label_set_text (GTK_LABEL(label_s3),"Functional Iteration(natural,shift)");
-                if((algorithms_choice.fi_shift==1)&&(algorithms_choice.fi_traditional==1)) gtk_label_set_text (GTK_LABEL(label_s3),"Functional Iteration(traditional,shift)");
-                if((algorithms_choice.fi_shift==1)&&(algorithms_choice.fi_Ubased==1)) gtk_label_set_text (GTK_LABEL(label_s3),"Functional Iteration(U-based,shift)");
-
-                if((algorithms_choice.fi_shift_u==1)&&(algorithms_choice.fi_natural==1)) gtk_label_set_text (GTK_LABEL(label_s3),"Functional Iteration(natural,shift, x user)");
-                if((algorithms_choice.fi_shift_u==1)&&(algorithms_choice.fi_traditional==1)) gtk_label_set_text (GTK_LABEL(label_s3),"Functional Iteration(traditional,shift, x user)");
-                if((algorithms_choice.fi_shift_u==1)&&(algorithms_choice.fi_Ubased==1)) gtk_label_set_text (GTK_LABEL(label_s3),"Functional Iteration(U-based,shift, x user)");
-
-
-
+        case 3: if((algorithms_choice.fz_0==1)&&(algorithms_choice.fi_natural==1))gtk_label_set_text (GTK_LABEL(label_s3),"Functional Iteration(natural,x(0)=0)");
+                if((algorithms_choice.fz_0==1)&&(algorithms_choice.fi_traditional==1))gtk_label_set_text (GTK_LABEL(label_s3),"Functional Iteration(traditional,x(0)=0)");
+                if((algorithms_choice.fz_0==1)&&(algorithms_choice.fi_Ubased==1))gtk_label_set_text (GTK_LABEL(label_s3),"Functional Iteration(U-based,x(0)=0)");
+                if((algorithms_choice.fz_1==1)&&(algorithms_choice.fi_natural==1)) gtk_label_set_text (GTK_LABEL(label_s3),"Functional Iteration(natural,x(0)=I)");
+                if((algorithms_choice.fz_1==1)&&(algorithms_choice.fi_traditional==1)) gtk_label_set_text (GTK_LABEL(label_s3),"Functional Iteration(traditional,x(0)=I)");
+                if((algorithms_choice.fz_1==1)&&(algorithms_choice.fi_Ubased==1)) gtk_label_set_text (GTK_LABEL(label_s3),"Functional Iteration(U-based,x(0)=I)");
+                if((algorithms_choice.fz_u==1)&&(algorithms_choice.fi_natural==1)) gtk_label_set_text (GTK_LABEL(label_s3),"Functional Iteration(natural,x user)");
+                if((algorithms_choice.fz_u==1)&&(algorithms_choice.fi_traditional==1)) gtk_label_set_text (GTK_LABEL(label_s3),"Functional Iteration(traditional,x user)");
+                if((algorithms_choice.fz_u==1)&&(algorithms_choice.fi_Ubased==1)) gtk_label_set_text (GTK_LABEL(label_s3),"Functional Iteration(U-based,x user)");
                 break;
         case 4: if( algorithms_choice.is_base==1) gtk_label_set_text (GTK_LABEL(label_s3),"Invariant Subspace(basic)");
                 if( algorithms_choice.is_balzer==1) gtk_label_set_text (GTK_LABEL(label_s3),"Invariant Subspace(Balzer)");
                 if( algorithms_choice.is_schur==1) gtk_label_set_text (GTK_LABEL(label_s3),"Invariant Subspace(Schur)");
                 break;
+	case 5: if( algorithms_choice.fz_0==1) gtk_label_set_text (GTK_LABEL(label_s3),"Newton Iterations,x(0)=0");
+		if( algorithms_choice.fz_1==1) gtk_label_set_text (GTK_LABEL(label_s3),"Newton Iterations,x(0)=I");
+		if( algorithms_choice.fz_u==1) gtk_label_set_text (GTK_LABEL(label_s3),"Newton Iterations,x user");
+		break;
         default: gtk_label_set_text (GTK_LABEL(label_s3),"Unknown");
         }
+switch(algorithms_choice.shift) {
+	case 0: gtk_label_set_text (GTK_LABEL(label_s5),"No Shift");
+		break;
+	case 1: gtk_label_set_text (GTK_LABEL(label_s5),"Simple Shift");
+		break;
+	case 2: gtk_label_set_text (GTK_LABEL(label_s5),"Tau Shift");
+		break;
+	case 3: gtk_label_set_text (GTK_LABEL(label_s5),"Double Shift");
+		break;
+	default:gtk_label_set_text (GTK_LABEL(label_s5),"Unknown");
+	}
+
+switch(algorithms_choice.dual) {
+	case 0: gtk_label_set_text (GTK_LABEL(label_s6),"Automatic");
+                break;
+        case 1:gtk_label_set_text (GTK_LABEL(label_s6),"Ramaswami");
+                break;
+        case 2:gtk_label_set_text (GTK_LABEL(label_s6)," Bright ");
+                break;
+        case 3:gtk_label_set_text (GTK_LABEL(label_s6),"  Both  ");
+                break;
+	case 4:gtk_label_set_text (GTK_LABEL(label_s6),"  None  ");
+		break;
+        default:gtk_label_set_text (GTK_LABEL(label_s6),"Unknown");
+	}
+
+
  switch(k){
         case 1:
                 if(goals_choice.qbd_g==1) {gtk_label_set_text (GTK_LABEL(label_s4),"G only"); break;}
