@@ -6,32 +6,34 @@
  * Largo Pontecorvo 5                                         *
  * 56127 Pisa                                                 *
  * Italy                                                      *
- * Version 1.3 - March 2007                                   *
+ * Version 2.1 - June  2009                                   *
  **************************************************************
  *
  *  structures.h
  *
  */
 
+struct main_menuitem_alg{
+
+};
+
 struct algorithms_str { 
-int type;   /* 1= Cyclic Reduction   2= Logarithmic reduction   3= Functional Iteration 4=Invariant Subspace  */
+int type; /* 1= Cyclic Reduction  2= Logarithmic reduction  3= Functional Iteration 4=Invariant Subspace 5=Newton */
+int shift; /* 0=no shift  1=simple shift  2=tau shift  3= double shift */
+int dual;  /* 0=auto dual 1=Ramaswami dual  2=Bright dual 3=Both duals 4=No Dual*/
 int cr_base;  /* 1= set 0=unset */
-int cr_shift;
 int cr_diag;
 int lr_base;
-int lr_shift;
 int lr_gth;
-int fi_base0;
-int fi_base1;
-int fi_base_u;
-int fi_shift;
-int fi_shift_u;
 int fi_natural;
 int fi_traditional;
 int fi_Ubased;
 int is_base;
 int is_balzer;
 int is_schur;
+int fz_0; /* for Functional Iteration and Newton */
+int fz_1;
+int fz_u;
 };
 
 struct goals_str{
@@ -67,8 +69,8 @@ int is_b;      /* 1= present 0=not present       */
 double alpha;    /* parameters used in some examples */
 double beta;
 int example;     /* 0 no example 1..9 examples */
-int fi_file_read; /* 0= a file for fi has not been read 1= has been read*/
-int fi_file_dim;  /* dimension of the file read - MUST be equal to dimension_m or it is not valid */
+int fz_file_read; /* 0= a file for fi or newton has not been read 1= has been read*/
+int fz_file_dim;  /* dimension of the file read - MUST be equal to dimension_m or it is not valid */
 struct algorithms_str alg;
 };
 
@@ -112,7 +114,7 @@ int eps;      /*lookup of the eps = epsilon(1.0d0) * 10 ** err */
 
 struct edita_str {
 int block;              /* memory of block A or B last dispalyed */
-int is_gru;		/* 0=no 1=g 2=r 3=u */
+int is_gru;		/* 0=no results of computations 1=g 2=r 3=u  */
 int is_positive;        /* 0: white is 0, black is 255; 1: white is 255, black is 0;  */
 int is_color;           /* =0 no color =1 color */
 int is_user;            /* 0: default 1: user settings */
