@@ -6,7 +6,7 @@
  * Largo Pontecorvo 5                                         *
  * 56127 Pisa                                                 *
  * Italy                                                      *
- * Version 1.3 - March 2007                                   *
+ * Version 2.1 - June  2009                                   *
  **************************************************************
  *
  *  view_mat.h - view and compare  G,R  - both callbacks and interfaces
@@ -48,11 +48,17 @@ void on_cancel_button_fsread_matrix_clicked   (GtkButton *, gpointer);
 void on_destroy_fsread_matrix (GtkWidget  *, gpointer );
 double view_get_data(int ,int );
 void view_fallback(void);
+void on_view_spectre_activate(GtkButton *, gpointer);
 
-/* prototipes ponte.f90 */
+
+/* prototipes futlis.f90 */
 void read_matg_(int *,int *, double *);
 void read_matr_(int *,int *, double *);
 void read_matu_(int *,int *, double *);
+void alloc_matev_(int *, int *);
+void read_matev_(int *,int *, double *);
+void write_matev_(int *,int *, double *);
+void sprad_g_(double *, int *,int *);
 
 /* prototypes rw.c */
 int watch_for_number(int , int , char *);
@@ -81,6 +87,7 @@ GtkWidget *button_matrix_r;   /* global to deselect when cancel */
 GtkWidget *button_matrix_u;   /*  global to deselect when cancel */
 GtkWidget *button_matrix_file; /* global to deselect when cancel */
 GtkWidget *button_matrix_test; /* global to select when cancel */
+GtkWidget *label_v233; /* spectre value */
 
 int is_view_fs_open;         /* 0 not opened, 1 opened */
 int is_view_comparison;      /* 0 no  1 comparison required: file will be read but only differences shown */
@@ -90,7 +97,7 @@ guchar *view_matvalue;       /* allocated in create_view_window, used by drawing
 guchar *rgb_view_matvalue;   /* allocated in create_view_window, used by drawing routines */
 double *vrs, vrmax,vrmin;  /* allocated in create_view_window, sum of rows  and maximum and minimum values */
 double *vcs, vcmax,vcmin;  /* allocated in create_view_window, sum of columns  and maximum and minimum values */
-double *view_file_data;      /* allocated in create_view_window, data read from file */
+/* double *view_file_data;  old code allocated in create_view_window, data read from file now matrix ev in fortran now */
 char view_file_name[256];
 int  view_dimension;
 int view_is_file; /* 0=no 1=yes */
@@ -110,3 +117,8 @@ struct running_problem_str committed,  completed; /* we save data here after suc
 
 /* globals rw.c */
 char pathgru_fs[512];    /* save name of last visited path */
+
+/* globals main.c */
+int is_smallscr;
+
+/*********************************************/
