@@ -6,7 +6,7 @@
  * Largo Pontecorvo 5                                         *
  * 56127 Pisa                                                 *
  * Italy                                                      *
- * Version 1.3 - March 2007                                   *
+ * Version 2.1 - June  2009                                   *
  **************************************************************
  *
  *  view_pi.c - view Pi quich hack  - both callbacks and interfaces
@@ -29,10 +29,10 @@
 
 #include "structures.h"
 #include "view_pi.h"
-
-#define  HPL 1000   /* drawing area side */
-#define  VPL 200   /* drawing area space */
-
+/*
+#define  HPL 1000    drawing area side 
+#define  VPL 200    drawing area space 
+*/
 /* View  Window  **** Interface */
 void
 create_view_pi_window(void)
@@ -52,8 +52,15 @@ struct  viewpi_str *data;
 GtkWidget *vbox_s1, *vbox_s2, *vbox_s3, *vbox_s4,*vbox_s5,*vbox_s6;
 GtkWidget *labelu_s1, *labelu_s2, *labelu_s3, *labelu_s4,*labelu_s5,*labelu_s6;
 GtkWidget *label_ss1, *label_ss2, *label_ss3, *label_ss4,*label_ss5,*label_ss6; 
-char tmp[256];
+char tmp[256],tmp1[256],tmp2[256],tmp3[256];
 int is_nan; /* 1=not a number discovered 0=0k */
+if(is_smallscr==0) { 
+		HPL=1000;
+		VPL=200;
+		} else {
+		HPL=700;
+                VPL=200;
+		}
 
 is_nan=0;
 data=calloc(1,sizeof(struct viewpi_str));
@@ -63,7 +70,9 @@ if(is_debug==1) printf("create_view_pi_window: data structure allocated data=%ld
 data->window_view_pi=gtk_window_new (GTK_WINDOW_TOPLEVEL);
 if (data->window_view_pi==NULL) {create_dialog_nogo2( window_main); return;};
 gtk_window_set_title (GTK_WINDOW (data->window_view_pi), "View Pi");
-gtk_window_set_default_size (GTK_WINDOW (data->window_view_pi), 800,250 );
+if(is_smallscr==0) gtk_window_set_default_size (GTK_WINDOW (data->window_view_pi), 800,250 );
+	else gtk_window_set_default_size (GTK_WINDOW (data->window_view_pi), 600,250 );
+gtk_window_set_resizable (GTK_WINDOW (data->window_view_pi),FALSE);
 gdk_rgb_init();
 
 if(is_debug==1) printf("create_view_pi_window: window allocated\n");
@@ -109,15 +118,15 @@ button_quit_view_pi = gtk_toolbar_append_element (GTK_TOOLBAR (toolbar_view_pi),
                                 tmp_toolbar_icon, NULL, NULL);
 gtk_widget_show(button_quit_view_pi);
 button_rescale_view_pi = gtk_toolbar_append_element (GTK_TOOLBAR (toolbar_view_pi),
-                                GTK_TOOLBAR_CHILD_BUTTON,
+                                GTK_TOOLBAR_CHILD_TOGGLEBUTTON,
                                 NULL,
-                                "Maximize\nMinimize",
+                                "Maximize\n\n(Minimize)",
                                 NULL, NULL,
                                 NULL, NULL, NULL);
 button_log_view_pi = gtk_toolbar_append_element (GTK_TOOLBAR (toolbar_view_pi),
-                                GTK_TOOLBAR_CHILD_BUTTON,
+                                GTK_TOOLBAR_CHILD_TOGGLEBUTTON,
                                 NULL,
-                                "Y Log\nLinear",
+                                "Y Log\n\n(Linear)",
                                 NULL, NULL,
                                 NULL, NULL, NULL);
 
@@ -170,41 +179,52 @@ if (completed.example !=0) {sprintf(tmp,"Example %d",completed.example);gtk_labe
         else {sprintf(tmp,"Read from File"); gtk_label_set_text (GTK_LABEL(label_ss2),tmp); }
 
 switch ((completed.alg).type){
-        case 1: if( (completed.alg).cr_base==1) gtk_label_set_text (GTK_LABEL(label_ss3),"Cyclic Reduction(basic)");
-                if( (completed.alg).cr_shift==1) gtk_label_set_text (GTK_LABEL(label_ss3),"Cyclic Reduction(shift)");
-                if( (completed.alg).cr_diag==1) gtk_label_set_text (GTK_LABEL(label_ss3),"Cyclic Reduction(diag.adj.)");
+        case 1: if( ((completed.alg).cr_base==1)&&((completed.alg).shift==0)) gtk_label_set_text (GTK_LABEL(label_ss3),"Cyclic Reduction\n(basic)");
+		if( ((completed.alg).cr_base==1)&&((completed.alg).shift==1)) gtk_label_set_text (GTK_LABEL(label_ss3),"Cyclic Reduction\n(shift)");
+		if( ((completed.alg).cr_base==1)&&((completed.alg).shift==2)) gtk_label_set_text (GTK_LABEL(label_ss3),"Cyclic Reduction\n(taushift)");
+		if( ((completed.alg).cr_base==1)&&((completed.alg).shift==3)) gtk_label_set_text (GTK_LABEL(label_ss3),"Cyclic Reduction\n(doubleshift)");
+                if( (completed.alg).cr_diag==1) gtk_label_set_text (GTK_LABEL(label_ss3),"Cyclic Reduction\n(diag.adj.)");
                 break;
-        case 2: if( (completed.alg).lr_base==1) gtk_label_set_text (GTK_LABEL(label_ss3),"Logarithmic Reduction(basic)");
-                if( (completed.alg).lr_shift==1) gtk_label_set_text (GTK_LABEL(label_ss3),"Logarithmic Reduction(shift)");
-                if( (completed.alg).lr_gth==1) gtk_label_set_text (GTK_LABEL(label_ss3),"Logarithmic Reduction(diag.adj.)");
+        case 2: if( ((completed.alg).lr_base==1)&&((completed.alg).shift==0)) gtk_label_set_text (GTK_LABEL(label_ss3),"Logarithmic Reduction\n(basic)");
+		if( ((completed.alg).lr_base==1)&&((completed.alg).shift==1)) gtk_label_set_text (GTK_LABEL(label_ss3),"Logarithmic Reduction\n(shift)");
+		if( ((completed.alg).lr_base==1)&&((completed.alg).shift==2)) gtk_label_set_text (GTK_LABEL(label_ss3),"Logarithmic Reduction\n(taushift)");
+		if( ((completed.alg).lr_base==1)&&((completed.alg).shift==3)) gtk_label_set_text (GTK_LABEL(label_ss3),"Logarithmic Reduction\n(doubleshift)");
+                if( (completed.alg).lr_gth==1) gtk_label_set_text (GTK_LABEL(label_ss3),"Logarithmic Reduction\n(diag.adj.)");
                 break;
-        case 3: if(((completed.alg).fi_base0==1)&&((completed.alg).fi_natural==1))gtk_label_set_text (GTK_LABEL(label_ss3),"Functional Iteration(natural,basic,x(0)=0)");
-                if(((completed.alg).fi_base0==1)&&((completed.alg).fi_traditional==1))gtk_label_set_text (GTK_LABEL(label_ss3),"Functional Iteration(traditional,basic,x(0)=0)");
-                if(((completed.alg).fi_base0==1)&&((completed.alg).fi_Ubased==1))gtk_label_set_text (GTK_LABEL(label_ss3),"Functional Iteration(U-based,basic,x(0)=0)");
-                if(((completed.alg).fi_base1==1)&&((completed.alg).fi_natural==1)) gtk_label_set_text (GTK_LABEL(label_ss3),"Functional Iteration(natural,basic,x(0)=I)");
-                if(((completed.alg).fi_base1==1)&&((completed.alg).fi_traditional==1)) gtk_label_set_text (GTK_LABEL(label_ss3),"Functional Iteration(traditional,basic,x(0)=I)");
-                if(((completed.alg).fi_base1==1)&&((completed.alg).fi_Ubased==1)) gtk_label_set_text (GTK_LABEL(label_ss3),"Functional Iteration(U-based,basic,x(0)=I)");
-                if(((completed.alg).fi_base_u==1)&&((completed.alg).fi_natural==1)) gtk_label_set_text (GTK_LABEL(label_ss3),"Functional Iteration(natural,basic,x user)");
-                if(((completed.alg).fi_base_u==1)&&((completed.alg).fi_traditional==1)) gtk_label_set_text (GTK_LABEL(label_ss3),"Functional Iteration(traditional,basic,x user)");
-                if(((completed.alg).fi_base_u==1)&&((completed.alg).fi_Ubased==1)) gtk_label_set_text (GTK_LABEL(label_ss3),"Functional Iteration(U-based,basic,x user)");
-                if(((completed.alg).fi_shift==1)&&((completed.alg).fi_natural==1)) gtk_label_set_text (GTK_LABEL(label_ss3),"Functional Iteration(natural,shift)");
-                if(((completed.alg).fi_shift==1)&&((completed.alg).fi_traditional==1)) gtk_label_set_text (GTK_LABEL(label_ss3),"Functional Iteration(traditional,shift)");
-                if(((completed.alg).fi_shift==1)&&((completed.alg).fi_Ubased==1)) gtk_label_set_text (GTK_LABEL(label_ss3),"Functional Iteration(U-based,shift)");
-                if(((completed.alg).fi_shift_u==1)&&((completed.alg).fi_natural==1)) gtk_label_set_text (GTK_LABEL(label_ss3),"Functional Iteration(natural,shift, x user)");
-                if(((completed.alg).fi_shift_u==1)&&((completed.alg).fi_traditional==1)) gtk_label_set_text (GTK_LABEL(label_ss3),"Functional Iteration(traditional,shift, x user)");
-                if(((completed.alg).fi_shift_u==1)&&((completed.alg).fi_Ubased==1)) gtk_label_set_text (GTK_LABEL(label_ss3),"Functional Iteration(U-based,shift, x user)");
+        case 3: if((completed.alg).fi_traditional==1)sprintf(tmp1,"Traditional");
+		if((completed.alg).fi_Ubased==1)sprintf(tmp1,"U-based");
+		if((completed.alg).fi_natural==1)sprintf(tmp1,"Natural");
+		if((completed.alg).shift==0)sprintf(tmp2,",");
+                if((completed.alg).shift==1)sprintf(tmp2,",Simple Shift,");
+                if((completed.alg).shift==2)sprintf(tmp2,",Tau Shift,");
+                if((completed.alg).shift==3)sprintf(tmp2,",Double Shift,");
+                if((completed.alg).fz_0==1)sprintf(tmp3,"x(0)=0");
+                if((completed.alg).fz_1==1)sprintf(tmp3,"x(0)=I");
+                if((completed.alg).fz_u==1)sprintf(tmp3,"user x(0)");
+		 sprintf(tmp,"Functional Iteration\n(%s%s\n%s)",tmp1,tmp2,tmp3);
+		 gtk_label_set_text (GTK_LABEL(label_ss3),tmp);
 
                 break;
-        case 4: if( (completed.alg).is_base==1) gtk_label_set_text (GTK_LABEL(label_ss3),"Invariant Subspace(basic)");
-                if( (completed.alg).is_balzer==1) gtk_label_set_text (GTK_LABEL(label_ss3),"Invariant Subspace(Balzer)");
-                if( (completed.alg).is_schur==1) gtk_label_set_text (GTK_LABEL(label_ss3),"Invariant Subspace(Schur)");
+        case 4: if( (completed.alg).is_base==1) gtk_label_set_text (GTK_LABEL(label_ss3),"Invariant Subspace\n(basic)");
+                if( (completed.alg).is_balzer==1) gtk_label_set_text (GTK_LABEL(label_ss3),"Invariant Subspace\n(Balzer)");
+                if( (completed.alg).is_schur==1) gtk_label_set_text (GTK_LABEL(label_ss3),"Invariant Subspace\n(Schur)");
                 break;
+	case 5:if((completed.alg).shift==0)sprintf(tmp2,",");
+                if((completed.alg).shift==1)sprintf(tmp2,",Simple Shift,");
+                if((completed.alg).shift==2)sprintf(tmp2,",Tau Shift,");
+                if((completed.alg).shift==3)sprintf(tmp2,",Double Shift,");
+                if((completed.alg).fz_0==1)sprintf(tmp3,"x(0)=0");
+                if((completed.alg).fz_1==1)sprintf(tmp3,"x(0)=I");
+                if((completed.alg).fz_u==1)sprintf(tmp3,"user x(0)");
+                 sprintf(tmp,"Newton Iteration\n(%s\n%s)",tmp2,tmp3);
+                 gtk_label_set_text (GTK_LABEL(label_ss3),tmp);
+		break;
         default: gtk_label_set_text (GTK_LABEL(label_ss3),"Unknown");
         }
 
-sprintf(tmp,"%d blocks (size %d)",completed.matrix_a_num,completed.dimension_m);
+sprintf(tmp,"%d blocks\n(size %d)",completed.matrix_a_num,completed.dimension_m);
 gtk_label_set_text (GTK_LABEL(label_ss4),tmp);
-sprintf(tmp,"%d blocks (size %d)",completed.matrix_b_num,completed.dimension_n);
+sprintf(tmp,"%d blocks\n(size %d)",completed.matrix_b_num,completed.dimension_n);
 gtk_label_set_text (GTK_LABEL(label_ss5),tmp);
 
 if(is_debug==1) printf("create_view_pi_window: beginning plot allocations\n");
@@ -249,7 +269,7 @@ data->is_maximized =0;
 data->is_log=0;
 if (is_debug==1) printf("create_view_pi_window: pi_num=%d, pi_min=%g, pi_max=%g, pi_sum=%g\n",data->pi_num, pi_min, pi_max, pi_sum);
 
-sprintf(tmp," %d sum=%g ",data->pi_num,pi_sum);
+sprintf(tmp," %d\nsum=%g ",data->pi_num,pi_sum);
 gtk_label_set_text (GTK_LABEL(label_ss6),tmp);
 
 
